********************************************************************************
*****           		    Replication File for     	           	       *****
*****            "The Non-Democratic Roots of Elite Capture:               *****
*****             Evidence from Soeharto Mayors in Indonesia"              *****
*****                      Monica Martinez-Bravo                           *****
*****                         Priya Mukherjee                              *****
*****                         Andreas Stegmann                             *****
******************************************************************************** 

********************************************************************************
***** 								Paper 								   *****                                         
********************************************************************************

clear all
set maxvar 32767 
set matsize 11000
set more off

*** Set path here

capture noisily cd ""

********************************************************************************


*****************************************************************************
** Table 1. Effect of Exposure to Soeharto Mayors on Quality of Governance **
*****************************************************************************

capture erase  "T1.xls"
capture erase  "T1.txt"

use "DataBupati_EGI.dta", clear

* Column 1

reg bribe_AP appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "T1.xls", bdec(3) nocons ctitle(Payments to Military) keep(appyr_predec) ///
	adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Column 2

reg bribe_AP i.appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "T1.xls", bdec(3) nocons ctitle(Payments to Military) keep(i.appyr_predec) ///
	adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	
	

use "DataBupati_PODES_2011.dta", clear	
	
* Column 3

reg z_score_edu appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "T1.xls", bdec(3) nocons ctitle(Z Score Education) keep(appyr_predec) ///
	adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Column 4
	
reg z_score_edu i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "T1.xls", bdec(3) nocons ctitle(Z Score Education) keep(i.appyr_predec) ///
	adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Column 5
	
reg z_score_health appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "T1.xls", bdec(3) nocons ctitle(Z Score Health) keep(appyr_predec) ///
	adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Column 6
	
reg z_score_health i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "T1.xls", bdec(3) nocons ctitle(Z Score Health) keep(i.appyr_predec) ///
	adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp	


**********************************************************************	
** Table 2: Effects of Exposure to Soeharto Mayors on Elite Capture **
**********************************************************************

capture erase  "T2.xls"
capture erase  "T2.txt"

use "DataBupati_Backgrounds.dta", clear

* Column 1. Panel A

reg soeharto_elite appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum soeharto_elite if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "T2.xls", adds(Mean, `mean') keep(appyr_predec) ctitle(Elite Persistence) bdec(3) nocons

* Column 1. Panel B

reg soeharto_elite i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum soeharto_elite if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "T2.xls", adds(Mean, `mean') keep(i.appyr_predec) ctitle(Elite Persistence) bdec(3) nocons

* Column 2. Panel A

reg winner_coalGOLKAR appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum winner_coalGOLKAR if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "T2.xls", adds(Mean, `mean') keep(appyr_predec) ctitle(Winner Golkar Coalition) nocons bdec(3)

* Column 2. Panel B

reg winner_coalGOLKAR i.appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum winner_coalGOLKAR if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "T2.xls", adds(Mean, `mean') keep(i.appyr_predec) ctitle(Winner Golkar Coalition) nocons bdec(3)


use "DataBupati_PODES_2005.dta", clear			
	
* Column 3. Panel A	
	
reg GolkarFirst appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum GolkarFirst if esample==1
local mean=r(mean)
egen temp=group(id_district) if esample==1
sum temp
local numkab=r(max)	
drop esample temp
outreg2 using "T2.xls", bdec(3) nocons keep(appyr_predec) ctitle(Golkar Most Voted 2004) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
		
* Column 3. Panel B

reg GolkarFirst i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum GolkarFirst if esample==1
local mean=r(mean)
egen temp=group(id_district) if esample==1
sum temp
local numkab=r(max)	
drop esample temp
outreg2 using "T2.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(Golkar Most Voted 2004) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')


use "DataBupati_Election_2004", clear			
	
* Column 4. Panel A

reg gol_2004_perc appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum gol_2004_perc if esample==1
local mean=r(mean)
egen temp=group(id_district) if esample==1
sum temp
local numkab=r(max)	
drop esample temp
outreg2 using "T2.xls", bdec(3) nocons keep(appyr_predec) ctitle(Votes Golkar 2004 District) adds(Mean, `mean', NumKabs, `numkab')
	
* Column 4. Panel B

reg gol_2004_perc i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum gol_2004_perc if esample==1
local mean=r(mean)
egen temp=group(id_district) if esample==1
sum temp
local numkab=r(max)	
drop esample temp
outreg2 using "T2.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(Votes Golkar 2004 District) adds(Mean, `mean', NumKabs, `numkab')
	
	
use "DataBupati_Election_2009.dta", clear

* Column 5. Panel A
	
reg gol_2009_perc appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum gol_2009_perc if esample==1
local mean=r(mean)
egen temp=group(id_district) if esample==1
sum temp
local numkab=r(max)	
drop esample temp
outreg2 using "T2.xls", bdec(3) nocons  keep(appyr_predec) ctitle(Golkar 2009 District) adds(Mean, `mean', NumKabs, `numkab')
		
* Column 5. Panel B
	
reg gol_2009_perc i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum gol_2009_perc if esample==1
local mean=r(mean)
egen temp=group(id_district) if esample==1
sum temp
local numkab=r(max)	
drop esample temp
outreg2 using "T2.xls", bdec(3) nocons  keep(i.appyr_predec) ctitle(Golkar 2009 District) adds(Mean, `mean', NumKabs, `numkab')
	
******************************************************************************	
** Table 3: Effects of Exposure to Soeharto Mayors on Political Competition **
******************************************************************************

capture erase  "T3.xls"
capture erase  "T3.txt"

use "DataBupati_Backgrounds.dta", clear

* Column 1. Panel A

reg num_cand appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum num_cand if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Num of Candidates) nocons bdec(3) keep(appyr_predec)

* Column 1. Panel B

reg num_cand i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum num_cand if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Num of Candidates) nocons bdec(3) keep(i.appyr_predec)

* Column 2. Panel A

reg num_indep_cand appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum num_indep_cand if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Num of Indep. Candidates) nocons bdec(3) keep(appyr_predec)

* Column 2. Panel B

reg num_indep_cand i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum num_indep_cand if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Num of Indep. Candidates) nocons bdec(3) keep(i.appyr_predec)

* Column 3. Panel A

reg sh_indep_cand appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum sh_indep_cand if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Share Indep. Candidates) nocons bdec(3) keep(appyr_predec)

* Column 3. Panel B

reg sh_indep_cand i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum sh_indep_cand if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Share Indep. Candidates) nocons bdec(3) keep(i.appyr_predec)

* Column 4. Panel A

reg herfindahl_index appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum herfindahl_index if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Herfindahl) nocons bdec(3) keep(appyr_predec)

* Column 4. Panel B

reg herfindahl_index i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum herfindahl_index if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Herfindahl) nocons bdec(3) keep(i.appyr_predec)

* Column 5. Panel A

reg incumbent_no_winner appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum incumbent_no_winner if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Incumbent not reelected) nocons bdec(3) keep(appyr_predec)

* Column 5. Panel B

reg incumbent_no_winner i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum incumbent_no_winner if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Incumbent not reelected) nocons bdec(3) keep(i.appyr_predec)

* Column 6. Panel A

reg z_score appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Z-Score) nocons bdec(3) keep(appyr_predec)

* Column 6. Panel B

reg z_score i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "T3.xls", adds(Mean, `mean') ctitle(Z-Score) nocons bdec(3) keep(i.appyr_predec)


***************************************************************************************
** Figure 2. Effects of Exposure to Soeharto Mayors on Public Good Provision (Panel) **
***************************************************************************************

use "DataBupati_PODES_Panel.dta", clear	
  
foreach var in pc_num_kindgarden_std pc_num_pri_std pc_num_hs_std z_score_edu tba_dum pc_num_puskesmas_std pc_num_midwives_std pc_num_doctors_std z_score_health {

areg  `var' c.appyr_predec##post_dum lpop* podes_yr*, cluster(id_district) abs(id_district) level(90)
parmest, level(90) saving("`var'.dta", replace)

}

foreach var in pc_num_kindgarden_std pc_num_pri_std pc_num_hs_std z_score_edu tba_dum pc_num_puskesmas_std pc_num_midwives_std pc_num_doctors_std z_score_health {
	
use "`var'.dta", clear
keep parm estimate min90 max90
gen depvar_name="`var'"
keep if parm=="1.post_dum#c.appyr_predec"
save "`var'.dta",replace
	
}

		
use "pc_num_kindgarden_std.dta", clear

foreach var in pc_num_pri_std pc_num_hs_std z_score_edu tba_dum ///
pc_num_puskesmas_std pc_num_midwives_std pc_num_doctors_std z_score_health {
append using "`var'.dta"
}

save "Figure_2_data.dta", replace	

use "Figure_2_data.dta", clear

keep if parm=="1.post_dum#c.appyr_predec"

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Education" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Health" if depvar_name==""
drop flag


local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="separation_1" if depvar_name==""
drop flag

gen order=.
replace order=1 if depvar_name=="Education"
replace depvar_name="z-score education" if depvar_name=="z_score_edu"
replace order=2 if depvar_name=="z-score education"
replace depvar_name="Number of kindergartens" if depvar_name=="pc_num_kindgarden_std"
replace order=3 if depvar_name=="Number of kindergartens"
replace depvar_name="Number of primary schools" if depvar_name=="pc_num_pri_std"
replace order=4 if depvar_name=="Number of primary schools"
replace depvar_name="Number of high schools" if depvar_name=="pc_num_hs_std"
replace order=5 if depvar_name=="Number of high schools"
replace order=6 if depvar_name=="separation_1"
replace depvar_name="." if depvar_name=="separation_1"
replace order=7 if depvar_name=="Health"
replace depvar_name="z-score health" if depvar_name=="z_score_health"
replace order=8 if depvar_name=="z-score health"
replace depvar_name="Number of basic health centers" if depvar_name=="pc_num_puskesmas_std"
replace order=9 if depvar_name=="Number of basic health centers"
replace depvar_name="Number of doctors" if depvar_name=="pc_num_doctors_std"
replace order=10 if depvar_name=="Number of doctors"
replace depvar_name="Number of midwives" if depvar_name=="pc_num_midwives_std"
replace order=11 if depvar_name=="Number of midwives"
replace depvar_name="Not using traditional birth attendants" if depvar_name=="tba_dum"
replace order=12 if depvar_name=="Not using traditional birth attendants"

sort order
sencode depvar_name, gen(parm_id) gsort(+order)

#delimit ;
eclplot estimate min90 max90 parm_id, horizontal
estopts(msymbol(O) mcolor(edkblue))
ciopts(lcolor(gs7))
ylabel(1(1)20, labcolor(white))
ylabel(1 "{bf:Education}" 2 "z-score education" 3 "Number of kindergartens" 4 "Number of primary schools" 5 "Number of high schools" ///
7 "{bf:Health}" 8 "z-score health" 9 "Number of basic health centers" 10 "Number of doctors" 11 "Number of midwives" 12 "Not using traditional birth attendants", nogrid labcolor(black)) ytitle("")

xlabel(-0.15(0.05)0.05) xtitle("Regression coefficient") 
yline(1, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
yline(7, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
yline(14, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
xline(0, lcolor(black)) 
xline(-0.05, lcolor(gs14)) 
xline(-0.10, lcolor(gs14)) 
graphregion(color(white)) bgcolor(white)
;
#delimit cr

graph export "Figure_2.pdf", replace	

* Erase data sets produced during intermediate steps
foreach var in pc_num_kindgarden_std pc_num_pri_std pc_num_hs_std z_score_edu ///
tba_dum pc_num_puskesmas_std pc_num_midwives_std pc_num_doctors_std z_score_health {
capture erase "`var'.dta"
}

capture erase "Figure_2_data.dta"




** Figure 3. Effects on Special Earmarked Grant 


use "DataBupati_LocalBudgets.dta", clear

forval i=2001(1)2007 {
	
reg  cent_gov_trans_dak_pc_`i' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
parmest, saving("cent_gov_trans_dak_pc_`i'.dta", replace)

}

forval i=2001(1)2007 {
	
	use "cent_gov_trans_dak_pc_`i'.dta", clear
	keep parm estimate min95 max95
	gen depvar_name="cent_gov_trans_dak_pc_`i'"
	gen year=`i'
	keep if parm=="appyr_predec"
	save "cent_gov_trans_dak_pc_`i'.dta",replace

}

use "cent_gov_trans_dak_pc_2001.dta", clear

forval i=2002(1)2007 {
	
append using "cent_gov_trans_dak_pc_`i'.dta"

}

save "Figure_3_data.dta", replace


use "Figure_3_data.dta", clear

keep if parm=="appyr_predec"

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Government: Wahid" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Government: Megawati" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Government: S.B. Yudhoyono" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="separation_1" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="separation_2" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="separation_3" if depvar_name==""
drop flag

gen order=.
replace order=1 if depvar_name=="Government: Wahid"
replace order=2 if depvar_name=="cent_gov_trans_dak_pc_2001" & year==2001
replace depvar_name="2001" if depvar_name=="cent_gov_trans_dak_pc_2001" & year==2001
replace order=3 if depvar_name=="separation_2"
replace depvar_name=".." if depvar_name=="separation_2"
replace order=4 if depvar_name=="Government: Megawati"
replace order=5 if depvar_name=="cent_gov_trans_dak_pc_2002" & year==2002
replace depvar_name="2002" if depvar_name=="cent_gov_trans_dak_pc_2002" & year==2002
replace order=6 if depvar_name=="cent_gov_trans_dak_pc_2003" & year==2003
replace depvar_name="2003" if depvar_name=="cent_gov_trans_dak_pc_2003" & year==2003
replace order=7 if depvar_name=="cent_gov_trans_dak_pc_2004" & year==2004
replace depvar_name="2004-" if depvar_name=="cent_gov_trans_dak_pc_2004" & year==2004
replace order=8 if depvar_name=="separation_3"
replace depvar_name="..." if depvar_name=="separation_3"
replace order=9 if depvar_name=="Government: S.B. Yudhoyono"
replace order=10 if depvar_name=="cent_gov_trans_dak_pc_2005" & year==2005
replace depvar_name="2005" if depvar_name=="cent_gov_trans_dak_pc_2005" & year==2005
replace order=11 if depvar_name=="cent_gov_trans_dak_pc_2006" & year==2006
replace depvar_name="2006" if depvar_name=="cent_gov_trans_dak_pc_2006" & year==2006
replace order=12 if depvar_name=="cent_gov_trans_dak_pc_2007" & year==2007
replace depvar_name="2007" if depvar_name=="cent_gov_trans_dak_pc_2007" & year==2007

drop if order==.
sort order
sencode depvar_name, gen(parm_id) gsort(+order)

#delimit ;
eclplot estimate min95 max95 parm_id, horizontal
estopts(msymbol(O) mcolor(edkblue))
ciopts(lcolor(gs7))
ylabel(1(1)12, labcolor(white))
ylabel( 1 "{bf:Government: Wahid}" ///
2 "2001" 4 "{bf:Government: Megawati}" 5 "2002" 6 "2003" ///
7 "2004" 9 "{bf:Government: S.B. Yudhoyono}" 10 "2005" 11 "2006" 12 "2007", nogrid labcolor(black)) ytitle("")
xlabel(-0.025(0.05)0.025) xtitle("Regression Coefficient Year of Appointment") 
yline(1, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
yline(4, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
yline(9, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
xline(0.025, lcolor(gs14))
xline(0, lcolor(black)) 
xline(-0.025, lcolor(gs14)) 

graphregion(color(white)) bgcolor(white)
;
#delimit cr
graph export "Figure_3.pdf", replace



* Erase data sets produced during intermediate steps

forval i=2001(1)2007 {

capture erase "cent_gov_trans_dak_pc_`i'.dta"

}
capture erase "Figure_3_data.dta"

********************************************************************************
***** 						    	Appendix A  					       *****
********************************************************************************
	
*****************************************************************************	
** Appendix A - Table 1. Cross-Tabulation of Appointment and Ending Timing **	
*****************************************************************************

use "DataBupati_Appointments.dta", clear
keep if num_splits==1 & gol_1992_perc!=.
tab appyr_predec appyr_predir

************************************************************************************
** Appendix A - Table 2. Effects of Exposure to Soeharto Mayors on Firm Extortion **
************************************************************************************

capture erase  "AT2.xls"
capture erase  "AT2.txt"

use "DataBupati_EGI.dta", clear

* Column 1. Panel A

reg bribe_AP appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Army,Baseline) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

	
* Column 1. Panel B

reg bribe_AP i.appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Army,Baseline) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	
* Column 2. Panel A

reg bribe_AP appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first if p75_dum==1 & know_bup_pers==0, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Army,Not Connected) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	
* Column 2. Panel B

reg bribe_AP i.appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first if p75_dum==1 & know_bup_pers==0, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Army,Not Connected) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Column 3. Panel A

reg bribe_locgov appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_locgov if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Local Gov,Baseline) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

	
* Column 3. Panel B

reg bribe_locgov i.appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_locgov if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Local Gov,Baseline) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	
* Column 4. Panel A

reg bribe_locgov appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first if p75_dum==1 & know_bup_pers==0, cluster(id_district)
	gen esample=e(sample)
	sum bribe_locgov if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Local Gov,Not Connected) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	
* Column 4. Panel B

reg bribe_locgov i.appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first if p75_dum==1 & know_bup_pers==0, cluster(id_district)
	gen esample=e(sample)
	sum bribe_locgov if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Local Gov,Not Connected) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	
* Column 5. Panel A

reg bribe_thug appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_thug if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Thugs,Baseline) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

	
* Column 5. Panel B

reg bribe_thug i.appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_thug if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Thugs,Baseline) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	
* Column 6. Panel A

reg bribe_thug appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first if p75_dum==1 & know_bup_pers==0, cluster(id_district)
	gen esample=e(sample)
	sum bribe_thug if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Thugs,Not Connected) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	
* Column 6. Panel B

reg bribe_thug i.appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first if p75_dum==1 & know_bup_pers==0, cluster(id_district)
	gen esample=e(sample)
	sum bribe_thug if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "AT2.xls", bdec(3) nocons ctitle(Bribes Thugs,Not Connected) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	
*******************************************************************************************
** Appendix A - Table 3. Effects of Exposure to Soeharto Mayors on Public Good Provision **	
*******************************************************************************************

capture erase  "AT3.xls"
capture erase  "AT3.txt"	
	
use "DataBupati_PODES_2011.dta", clear	


* Columns 1 to 3.  
foreach var in z_score_edu z_score_health z_score_services {
	* Panel A
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "AT3.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2011) adds(Mean, `mean', clust, e(N_clust))

	* Panel B	
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "AT3.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2011) adds(Mean, `mean', clust, e(N_clust))
	
	}

use "DataBupati_PODES_Panel.dta", clear
	
* Columns 1 to 3.	
foreach var in z_score_edu z_score_health z_score_services {
	* Panel C
	areg  `var' c.appyr_predec##post_dum lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "AT3.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	
	* Panel D
	areg  `var' appyr_predec##post_dum lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "AT3.xls", bdec(3) nocons keep(appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	
	}		
	

*****************************************************************************************	
** Appendix A - Table 4A. Effects of Soeharto Mayors on Public Goods Outcomes (Health) **
*****************************************************************************************

capture erase  "AT4A.xls"
capture erase  "AT4A.txt"	

use "DataBupati_PODES_2011_Add.dta", clear

* Columns 1 & 2

foreach var of varlist num_deaths_under5_2011_pc num_deaths_mothers_2011_pc {
 
* Panel A 
reg `var' appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT4A.xls", keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(`var') nocons bdec(3)

* Panel B
reg `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT4A.xls", keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(`var') nocons bdec(3)

}

use "DataBupati_SUSENAS_2009_AddHealth.dta", clear

* Columns 3 to 6

foreach var of varlist z_score_illness_u5 illness_diarrhea_u5 z_score_illness illness_diarrhea {

* Panel A
 
reg `var' appyr_predec gol_1992_perc pdi_1992_perc isdum* i.gender i.age, cluster(id_district)
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT4A.xls", keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(`var') nocons bdec(3)

* Panel B

reg `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum* i.gender i.age, cluster(id_district)
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT4A.xls", keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(`var') nocons bdec(3)

}

********************************************************************************************	
** Appendix A - Table 4B. Effects of Soeharto Mayors on Public Goods Outcomes (Education) **
********************************************************************************************

capture erase  "AT4B.xls"
capture erase  "AT4B.txt"

use "DataBupati_DAPOER_AddEdu.dta", clear

* Columns 1 to 2 & 4 to 7

foreach var of varlist stu_tea_ratio_pri_09 stu_tea_ratio_high_09 net_enrollm_pri_2009 net_enrollm_high_09 nat_exam_pri_2009 nat_exam_ju_2009 {

* Panel A 

reg `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT4B.xls", keep(appyr_predec) adds(Mean, `mean') ctitle(`var') nocons bdec(3)

* Panel B

reg `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT4B.xls", keep(i.appyr_predec) adds(Mean, `mean') ctitle(`var') nocons bdec(3)

}

use "DataBupati_PODES_2003_Add.dta", clear

* Column 3

* Panel A
 
reg num_dropouts_2003_pc appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_dropouts_2003_pc if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT4B.xls", ///
keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_dropouts_2003_pc) nocons

* Panel B

reg num_dropouts_2003_pc i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_dropouts_2003_pc if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT4B.xls", ///
keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_dropouts_2003_pc) nocons



*****************************************************************************************************	
** Appendix A - Table 5. Effects of Exposure to Soeharto Mayors on Quality of Local Accountability **
*****************************************************************************************************

capture erase  "AT5.xls"
capture erase  "AT5.txt"

use "DataBupati_Accountability", clear

* Panel A

* Column 4

reg reelection_st badperformance_dum_50_st##c.appyr_predec_adj gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum reelection_st if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT5.xls", keep(badperformance_dum_50_st##c.appyr_predec_adj) adds(Mean, `mean') ctitle(First Pilkada, 50) nocons bdec(3)

* Column 3

reg reelection_st badperformance_dum_40_st##c.appyr_predec_adj gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum reelection_st if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT5.xls", keep(badperformance_dum_40_st##c.appyr_predec_adj) adds(Mean, `mean') ctitle(First Pilkada, 40) nocons bdec(3)

* Column 2

reg reelection_st badperformance_dum_30_st##c.appyr_predec_adj gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum reelection_st if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT5.xls", keep(badperformance_dum_30_st##c.appyr_predec_adj) adds(Mean, `mean') ctitle(First Pilkada, 30) nocons bdec(3)

* Column 1

reg reelection_st badperformance_dum_20_st##c.appyr_predec_adj gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum reelection_st if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT5.xls", keep(badperformance_dum_20_st##c.appyr_predec_adj) adds(Mean, `mean') ctitle(First Pilkada, 20) nocons bdec(3)

* Panel B

* Column 4

reg reelection_nd badperformance_dum_50_nd##c.appyr_predec_adj gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum reelection_nd if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT5.xls", keep(badperformance_dum_50_nd##c.appyr_predec_adj) adds(Mean, `mean') ctitle(Second Pilkada, 50) nocons bdec(3)

* Column 3

reg reelection_nd badperformance_dum_40_nd##c.appyr_predec_adj gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum reelection_nd if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT5.xls", keep(badperformance_dum_40_nd##c.appyr_predec_adj) adds(Mean, `mean') ctitle(Second Pilkada, 40) nocons bdec(3)

* Column 2

reg reelection_nd badperformance_dum_30_nd##c.appyr_predec_adj gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum reelection_nd if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT5.xls", keep(badperformance_dum_30_nd##c.appyr_predec_adj) adds(Mean, `mean') ctitle(Second Pilkada, 30) nocons bdec(3)

* Column 1

reg reelection_nd badperformance_dum_20_nd##c.appyr_predec_adj gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum reelection_nd if esample==1
local mean=r(mean)
drop esample
outreg2 using "AT5.xls", keep(badperformance_dum_20_nd##c.appyr_predec_adj) adds(Mean, `mean') ctitle(Second Pilkada, 20) nocons bdec(3)



********************************************************************************
*****                            Appendix B					       	       *****
********************************************************************************

*************************************************************************
** Appendix B - Table 1. Distribution of Districts by Appointment Year **
*************************************************************************	

use "DataBupati_Appointments.dta", clear

count		
tab appyr_predec
tab appyr_predec if gol_1992_perc!=.
tab appyr_predec if gol_1992_perc!=. & num_splits==1
tab appyr_predec if appyr_predec!=1998 & gol_1992_perc!=. & num_splits==1


**********************************************
** Appendix B - Table 2. Summary Statistics **
**********************************************

use "DataBupati_SumStats.dta", clear

* Panel A. Measures of Political Attitudes

sum gol_neworder gol_1999_perc gol_2004_perc pdi_neworder pdi_1999_perc pdi_2004_perc herf_index_1992 herf_index_2004    

* Panel B. Mayors and Administrative Structure 
sum appyr_stl_soeharto appyr_predec appyr_predir

* Panel C. District Characteristics & Public Good Provision 
use "DataBupati_PODES_1993_dis.dta", clear

sum num_vil population_1993 num_pri_ph num_hs_ph num_kindgarden_ph

sum num_puskesmas_ph num_midwives_ph num_doctors_ph tba_dum if health_complete_dum==1

********************************************
** Appendix B - Table 3. Endogeneity Test **
********************************************

capture erase  "BT3.xls"
capture erase  "BT3.txt"

* PANEL A. Measures of Political Support
use "DataBupati_Endogeneity", clear

foreach xx in 1971 1977 1982 1987 1992 {
	gen gol=gol_`xx'_perc

reg  appyr_predec gol isd*, robust
 outreg2 gol using "BT3.xls", bdec(3) side nocons ctitle(PANEL A, Golkar `xx')

reg  appyr_predec gol isd*, robust beta
 outreg2 gol using "BT3.xls", bdec(3) nocons stats(beta) ctitle(beta, Golkar `xx')
 
 drop gol
 }

reg  appyr_predec pdi_1992_perc isd*, robust
 outreg2 pdi_1992_perc using "BT3.xls", bdec(3) side nocons ctitle(PANEL A, PDI 1992)

reg  appyr_predec pdi_1992_perc isd*, robust beta
 outreg2 pdi_1992_perc using "BT3.xls", bdec(3) nocons stats(beta) ctitle(beta, PDI 1992)
 

foreach yr in 1982 1987 1992 {

reg  appyr_predec herf_`yr' isd*, robust
 outreg2 gol using "BT3.xls", bdec(3) side nocons ctitle(PANEL A, Herfindahl `yr')

reg  appyr_predec herf_`yr' isd*, robust beta
 outreg2 gol using "BT3.xls", bdec(3) nocons stats(beta) ctitle(beta, Herfindahl `yr')
 }
 

* Panel B: Measures of Political Stability

global covarUNSFIR "incidents_avg_90_93 totkil_avg_90_93 totinj_avg_90_93"
	
foreach var in $covarUNSFIR{
 gen covar=`var'
 reg  appyr_predec covar isdum*, robust
 outreg2 covar using "BT3.xls", bdec(3) side nocons ctitle(PANEL B, `var')

 reg  appyr_predec covar isdum*, robust
 outreg2 covar using "BT3.xls", bdec(3) side nocons stats(beta) ctitle(beta, `var')
 
 drop covar
 }

reg  appyr_predec prev_term_length isd*, robust
 outreg2 prev_term_length using "BT3.xls", bdec(3) side nocons ctitle(PANEL B, prev_term_length)

reg  appyr_predec  prev_term_length isd*, robust beta
 outreg2 prev_term_length using "BT3.xls", bdec(3) nocons stats(beta) ctitle(beta, prev_term_length)
 
 
* PANEL C. Public Good Provision and Economic Variables
 
use "DataBupati_PODES_1993.dta", clear

/* Defining Covariates */
# delimit ;
global covars "lpopulation_1993 popdensity_1993 num_pri_ph num_hs_ph num_kindgarden_ph 
safedrink garbage_bin toilet_pub electr_kersosene wide_mainroad rel_frag" ;
# delimit cr

foreach var in $covars {
 gen covar=`var'
 reg  appyr_predec covar isdum*, cluster(id_district) 
 outreg2 covar using "BT3.xls", bdec(3) side nocons ctitle(PANEL C, `var') adds(clust, e(N_clust))
 
 reg  appyr_predec covar isdum*, beta
 outreg2 covar using "BT3.xls", bdec(3) side nocons stats(beta) ctitle(beta, `var')

 drop covar
 }
 
# delimit ;
global covars_health "num_puskesmas_ph num_doctors_ph num_midwives_ph tba_dum";
# delimit cr

foreach var in $covars_health {
 gen covar=`var'
 reg  appyr_predec covar isdum* if health_complete_dum==1, cluster(id_district) 
 outreg2 covar using "BT3.xls", bdec(3) side nocons ctitle(PANEL C, `var') adds(clust, e(N_clust))
 
 reg  appyr_predec covar isdum* if health_complete_dum==1, beta
 outreg2 covar using "BT3.xls", bdec(3) side nocons stats(beta) ctitle(beta, `var')

 drop covar
 }

use "DataBupati_Endogeneity", clear

global covars "ltot_rev_pc_1994 ltot_loc_rev_pc_1994"

foreach var in $covars {
 gen covar=`var'
 reg  appyr_predec covar isdum*, robust
 outreg2 covar using "BT3.xls", bdec(3) side nocons ctitle(PANEL C, `var')
 
 reg  appyr_predec covar isdum*, robust beta
 outreg2 covar using "BT3.xls", bdec(3) stats(beta) nocons ctitle(beta, `var')

 drop covar
 }

****************************************************************************
** Appendix B - Table 4. Characteristics of Mayors Appointed in 1994-1998 **
****************************************************************************

capture erase "BT4.xls"
capture erase "BT4.txt"

use "DataBupati_SoehartoMayors_94_98", clear


* Columns 1 to 4

foreach var of varlist years_schooling age_at_appointment native_dum miss_background {

* Panel A

reg `var' appyr_predec gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1998, robust
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT4.xls", keep(appyr_predec) adds(Mean, `mean') ctitle(Panel A, `var') nocons bdec(3)

* Panel B

reg `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1998, robust
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT4.xls", keep(i.appyr_predec) adds(Mean, `mean') ctitle(Panel B, `var') nocons bdec(3)

* Panel C

reg `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT4.xls", keep(i.appyr_predec) adds(Mean, `mean') ctitle(Panel C, `var') nocons bdec(3)

}

********************************************************
** Appendix B - Tables 5A, 5B, 5C, 6A, 6B, 6C, 6D, 6E **
********************************************************

******************************************************
** Appendix B - Table 5A Panel A & Table 6A Panel A **
******************************************************

capture erase  "BT5A.xls"
capture erase  "BT5A.txt"

capture erase  "BT6A.xls"
capture erase  "BT6A.txt"

use "DataBupati_EGI.dta", clear

* Appendix B - Table 5A. Panel A
* Column 2
reg bribe_AP appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first if appyr_predec!=1997, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT5A.xls", bdec(3) nocons ctitle(bribe_AP) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix Table 6A. Panel A
* Column 2
reg bribe_AP i.appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first if appyr_predec!=1997, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT6A.xls", bdec(3) nocons ctitle(bribe_AP) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

global controlset_predec incidents_appyr_predec totkil_appyr_predec totinj_appyr_predec

* Appendix B - Table 5A. Panel A
* Column 3
reg bribe_AP appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT5A.xls", bdec(3) nocons ctitle(bribe_AP) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix B - Table 6A. Panel A
* Column 3
reg bribe_AP i.appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT6A.xls", bdec(3) nocons ctitle(bribe_AP) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

global controlset_predir incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir

* Appendix B - Table 5A. Panel A
* Column 5
reg bribe_AP appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT5A.xls", bdec(3) nocons ctitle(bribe_AP) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix B - Table 6A. Panel A
* Column 5
reg bribe_AP i.appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT6A.xls", bdec(3) nocons ctitle(bribe_AP) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix B - Table 5A. Panel A
* Column 7
reg bribe_AP appyr_predec conflict_direl gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT5A.xls", bdec(3) nocons ctitle(bribe_AP) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix B - Table 6A. Panel A
* Column 7
reg bribe_AP i.appyr_predec conflict_direl gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT6A.xls", bdec(3) nocons ctitle(bribe_AP) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

	
global controlset_predec ltot_rev_pc_predec ltot_loc_rev_pc_predec

* Appendix B - Table 5A. Panel A
* Column 4
reg bribe_AP appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT5A.xls", bdec(3) nocons ctitle(bribe_AP) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix B - Table 6A. Panel A
* Column 4
reg bribe_AP i.appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT6A.xls", bdec(3) nocons ctitle(bribe_AP) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp



global controlset_predir ltot_rev_pc_predir ltot_loc_rev_pc_predir

* Appendix B - Table 5A. Panel A
* Column 6
reg bribe_AP appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT5A.xls", bdec(3) nocons ctitle(bribe_AP) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix B - Table 6A. Panel A
* Column 6
reg bribe_AP i.appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT6A.xls", bdec(3) nocons ctitle(bribe_AP) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

		

global controlset_direl ltot_rev_pc_direl ltot_loc_rev_pc_direl

* Appendix B - Table 5A. Panel A
* Column 8
reg bribe_AP appyr_predec $controlset_direl gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT5A.xls", bdec(3) nocons ctitle(bribe_AP) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix B - Table 6A. Panel A
* Column 8
reg bribe_AP i.appyr_predec $controlset_direl gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT6A.xls", bdec(3) nocons ctitle(bribe_AP) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp


* Appendix B - Table 5A. Panel A
* Column 9
reg bribe_AP appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT5A.xls", bdec(3) nocons ctitle(bribe_AP) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix B - Table 6A. Panel A
* Column 9
reg bribe_AP i.appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT6A.xls", bdec(3) nocons ctitle(bribe_AP) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

	
* Appendix B - Table 5A. Panel A
* Column 10
reg bribe_AP appyr_predec i.bup_experience_dum* gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT5A.xls", bdec(3) nocons ctitle(bribe_AP) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Appendix B - Table 6A. Panel A
* Column 10
reg bribe_AP i.appyr_predec i.bup_experience_dum* gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT6A.xls", bdec(3) nocons ctitle(bribe_AP) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp


*********************************************************************************
** Appendix B - Table 5A. Panel B, C & Table 6A. Panel B & Table 6B. Panel A **
*********************************************************************************

capture erase  "BT6B.xls"
capture erase  "BT6B.txt"


use "DataBupati_PODES_Panel.dta", clear	 
  
* Appendix B - Table 5A. Panel B, C
* Column 2

foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predec##post_dum lpop* podes_yr* if appyr_predec!=1997, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT5A.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	
	}

* Appendix B - Table 6A. Panel B
* Column 2

	areg  z_score_edu appyr_predec##post_dum lpop* podes_yr* if appyr_predec!=1997, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6A.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_edu, PANEL) adds(Mean, `mean', clust, e(N_clust))

* Appendix B - Table 6B. Panel A
* Column 2

	areg  z_score_health appyr_predec##post_dum lpop* podes_yr* if appyr_predec!=1997, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6B.xls", bdec(3) nocons  ///
	keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_health, PANEL) adds(Mean, `mean', clust, e(N_clust))

		
* Appendix B - Table 5A. Panel B, C
* Column 3 
foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predec##post_dum podes_yr*##c.incidents_appyr_predec podes_yr*##c.totkil_appyr_predec podes_yr*##c.totinj_appyr_predec lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT5A.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	}
* Appendix B - Table 6A. Panel B
* Column 3	
	areg  z_score_edu appyr_predec##post_dum podes_yr*##c.incidents_appyr_predec podes_yr*##c.totkil_appyr_predec podes_yr*##c.totinj_appyr_predec lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6A.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_edu, PANEL) adds(Mean, `mean', clust, e(N_clust))
	
* Appendix B - Table 6B. Panel A
* Column 3	
	areg  z_score_health appyr_predec##post_dum podes_yr*##c.incidents_appyr_predec podes_yr*##c.totkil_appyr_predec podes_yr*##c.totinj_appyr_predec lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6B.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_health, PANEL) adds(Mean, `mean', clust, e(N_clust))

	
* Appendix B - Table 5A. Panel B, C
* Column 5 
foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predec##post_dum podes_yr*##c.incidents_appyr_predir podes_yr*##c.totkil_appyr_predir podes_yr*##c.totinj_appyr_predir lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT5A.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	}
	
* Appendix B - Table 6A. Panel B
* Column 5
	areg  z_score_edu appyr_predec##post_dum podes_yr*##c.incidents_appyr_predir podes_yr*##c.totkil_appyr_predir podes_yr*##c.totinj_appyr_predir lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6A.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_edu, PANEL) adds(Mean, `mean', clust, e(N_clust))
	
* Appendix B - Table 6B. Panel A
* Column 5	
	areg  z_score_health appyr_predec##post_dum podes_yr*##c.incidents_appyr_predir podes_yr*##c.totkil_appyr_predir podes_yr*##c.totinj_appyr_predir lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6B.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_health, PANEL) adds(Mean, `mean', clust, e(N_clust))
		

* Appendix B - Table 5A. Panel B, C
* Column 7 
foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predec##post_dum podes_yr*##c.conflict_direl lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT5A.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	}

* Appendix B - Table 6A. Panel B
* Column 7		
	areg  z_score_edu appyr_predec##post_dum podes_yr*##c.conflict_direl lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6A.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_edu, PANEL) adds(Mean, `mean', clust, e(N_clust))


* Appendix B - Table 6B. Panel A
* Column 7	
	areg  z_score_health appyr_predec##post_dum podes_yr*##c.conflict_direl lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6B.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_health, PANEL) adds(Mean, `mean', clust, e(N_clust))
	
	
* Appendix B - Table 5A. Panel B, C
* Column 4 
foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predec##post_dum podes_yr*##c.ltot_rev_pc_predec podes_yr*##c.ltot_loc_rev_pc_predec lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT5A.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	}
	
* Appendix B - Table 6A. Panel B
* Column 4	
	areg  z_score_edu appyr_predec##post_dum podes_yr*##c.ltot_rev_pc_predec podes_yr*##c.ltot_loc_rev_pc_predec lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6A.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_edu, PANEL) adds(Mean, `mean', clust, e(N_clust))
	
* Appendix B - Table 6B. Panel A
* Column 4
	areg  z_score_health appyr_predec##post_dum podes_yr*##c.ltot_rev_pc_predec podes_yr*##c.ltot_loc_rev_pc_predec lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6B.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_health, PANEL) adds(Mean, `mean', clust, e(N_clust))
	
* Appendix B - Table 5A. Panel B, C
* Column 6 
foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predec##post_dum podes_yr*##c.ltot_rev_pc_predir podes_yr*##c.ltot_loc_rev_pc_predir lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT5A.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	}
* Appendix B - Table 6A. Panel B
* Column 6	
	areg  z_score_edu appyr_predec##post_dum podes_yr*##c.ltot_rev_pc_predir podes_yr*##c.ltot_loc_rev_pc_predir lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6A.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) /// 
	ctitle(z_score_edu, PANEL) adds(Mean, `mean', clust, e(N_clust))

* Appendix B - Table 6B. Panel A
* Column 6		
	areg  z_score_health appyr_predec##post_dum podes_yr*##c.ltot_rev_pc_predir podes_yr*##c.ltot_loc_rev_pc_predir lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6B.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_health, PANEL) adds(Mean, `mean', clust, e(N_clust))


* Appendix B - Table 5A. Panel B, C
* Column 8 
foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predec##post_dum podes_yr*##c.ltot_rev_pc_direl podes_yr*##c.ltot_loc_rev_pc_direl lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT5A.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	}
* Appendix B - Table 6A. Panel B
* Column 8			
	areg  z_score_edu appyr_predec##post_dum podes_yr*##c.ltot_rev_pc_direl podes_yr*##c.ltot_loc_rev_pc_direl lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6A.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_edu, PANEL) adds(Mean, `mean', clust, e(N_clust))
	
* Appendix B - Table 6B. Panel A
* Column 8			
	areg  z_score_health appyr_predec##post_dum podes_yr*##c.ltot_rev_pc_direl podes_yr*##c.ltot_loc_rev_pc_direl lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6B.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_health, PANEL) adds(Mean, `mean', clust, e(N_clust))


* Appendix B - Table 5A. Panel B, C
* Column 9 
foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predec##post_dum podes_yr*##pilk_yr_dum05 podes_yr*##pilk_yr_dum06 podes_yr*##pilk_yr_dum07p lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT5A.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	}
* Appendix B - Table 6A. Panel B
* Column 9	
	areg  z_score_edu appyr_predec##post_dum podes_yr*##pilk_yr_dum05 podes_yr*##pilk_yr_dum06 podes_yr*##pilk_yr_dum07p lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6A.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_edu, PANEL) adds(Mean, `mean', clust, e(N_clust))

* Appendix B - Table 6B. Panel A
* Column 9			
	areg  z_score_health appyr_predec##post_dum podes_yr*##pilk_yr_dum05 podes_yr*##pilk_yr_dum06 podes_yr*##pilk_yr_dum07p lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6B.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(z_score_health, PANEL) adds(Mean, `mean', clust, e(N_clust))
	

	
* Appendix B - Table 5A. Panel B, C
* Column 10 	
foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predec##post_dum i.bup_experience lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT5A.xls", bdec(3) nocons keep(c.appyr_predec##post_dum) ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	}
* Appendix B - Table 6B. Panel A
* Column 10		
	areg  z_score_edu appyr_predec##post_dum i.bup_experience lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_edu if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6A.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ctitle(z_score_edu, PANEL) adds(Mean, `mean', clust, e(N_clust))

* Appendix B - Table 6A. Panel B
* Column 10		
	areg  z_score_health appyr_predec##post_dum i.bup_experience lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum z_score_health if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT6B.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1.post_dum) ctitle(z_score_health, PANEL) adds(Mean, `mean', clust, e(N_clust))
				
		
		
***********************************************************************************************************************
** Appendix B - Table 5B. Panel A, B & Table 5C. Panel C & Table 6B. Panel B & Table 6C. Panel A & Table 6E. Panel A **
***********************************************************************************************************************	
	
capture erase  "BT5B.xls"
capture erase  "BT5B.txt"

capture erase  "BT5C.xls"
capture erase  "BT5C.txt"

capture erase  "BT6C.xls"
capture erase  "BT6C.txt"

capture erase  "BT6E.xls"
capture erase  "BT6E.txt"


use "DataBupati_Backgrounds.dta", clear

* Appendix B - Table 5B. Panel A
* Column 2		
reg soeharto_elite appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6B. Panel B
* Column 2
reg soeharto_elite i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(i.appyr_predec)


* Appendix B - Table 5B. Panel B
* Column 2
reg winner_coalGOLKAR appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(appyr_predec)


* Appendix B - Table 5C. Panel C
* Column 2
reg z_score appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5C.xls", adds(Mean, `mean') ctitle(z_score) nocons bdec(3) keep(appyr_predec)


* Appendix B - Table 6C. Panel A
* Column 2
reg winner_coalGOLKAR i.appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(i.appyr_predec)


* Appendix B - Table 6E. Panel A
* Column 2
reg z_score i.appyr_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6E.xls", adds(Mean, `mean') ctitle(z_score, Col 2) nocons bdec(3) keep(i.appyr_predec)


global controlset_predec incidents_appyr_predec totkil_appyr_predec totinj_appyr_predec

* Appendix B - Table 5B. Panel A
* Column 3
reg soeharto_elite appyr_predec $controlset_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6B. Panel B
* Column 3
reg soeharto_elite i.appyr_predec $controlset_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(i.appyr_predec)

* Appendix B - Table 5B. Panel B
* Column 3
reg winner_coalGOLKAR appyr_predec $controlset_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(appyr_predec)

* Appendix Table 5C. Panel C
* Column 3
reg z_score appyr_predec $controlset_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5C.xls", adds(Mean, `mean') ctitle(z_score) nocons bdec(3) keep(appyr_predec)

* Appendix Table 6C. Panel A
* Column 3
reg winner_coalGOLKAR i.appyr_predec $controlset_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(i.appyr_predec)

* Appendix Table 6E. Panel A
* Column 3
reg z_score i.appyr_predec $controlset_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6E.xls", adds(Mean, `mean') ctitle(z_score) nocons bdec(3) keep(i.appyr_predec)



global controlset_predir incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir

* Appendix B - Table 5B. Panel A
* Column 5
reg soeharto_elite appyr_predec incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6B. Panel B
* Column 5
reg soeharto_elite i.appyr_predec incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(i.appyr_predec)

* Appendix B - Table 5B. Panel B
* Column 5
reg winner_coalGOLKAR appyr_predec incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 5C. Panel C
* Column 5
reg z_score appyr_predec incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5C.xls", adds(Mean, `mean') ctitle(z_score) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6C. Panel A
* Column 5
reg winner_coalGOLKAR i.appyr_predec incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(i.appyr_predec)

* Appendix B - Table 6E. Panel A
* Column 5
reg z_score i.appyr_predec incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6E.xls", adds(Mean, `mean') ctitle(z_score, Col 5) nocons bdec(3) keep(i.appyr_predec)



global controlset_predec ltot_rev_pc_predec ltot_loc_rev_pc_predec

* Appendix B - Table 5B. Panel A
* Column 4
reg soeharto_elite appyr_predec $controlset_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(soeharto_elite) bdec(3) nocons keep(appyr_predec)

* Appendix B - Table 6B. Panel B
* Column 4
reg soeharto_elite i.appyr_predec $controlset_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6B.xls", adds(Mean, `mean') ctitle(soeharto_elite) bdec(3) nocons keep(i.appyr_predec)

* Appendix B - Table 5B. Panel B
* Column 4
reg winner_coalGOLKAR appyr_predec $controlset_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) bdec(3) nocons keep(appyr_predec)

* Appendix B - Table 5C. Panel C
* Column 4
reg z_score appyr_predec $controlset_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5C.xls", adds(Mean, `mean') ctitle(z_score) bdec(3) nocons keep(appyr_predec)

* Appendix B - Table 6C. Panel A
* Column 4
reg winner_coalGOLKAR i.appyr_predec $controlset_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) bdec(3) nocons keep(i.appyr_predec)

* Appendix B - Table 6E. Panel A
* Column 4
reg z_score i.appyr_predec $controlset_predec early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6E.xls", adds(Mean, `mean') ctitle(z_score, Col 4) bdec(3) nocons keep(i.appyr_predec)


global controlset_predir ltot_rev_pc_predir ltot_loc_rev_pc_predir

* Appendix B - Table 5B. Panel A
* Column 6
reg soeharto_elite appyr_predec $controlset_predir early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(soeharto_elite) bdec(3) nocons keep(appyr_predec)

* Appendix B - Table 6B. Panel B
* Column 6
reg soeharto_elite i.appyr_predec $controlset_predir early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6B.xls", adds(Mean, `mean') ctitle(soeharto_elite) bdec(3) nocons keep(i.appyr_predec)
 
* Appendix B - Table 6B. Panel B
* Column 6
reg winner_coalGOLKAR appyr_predec $controlset_predir early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) bdec(3) nocons keep(appyr_predec)

* Appendix B - Table 5C. Panel C
* Column 6
reg z_score appyr_predec $controlset_predir early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5C.xls", adds(Mean, `mean') ctitle(z_score) bdec(3) nocons keep(appyr_predec)

* Appendix B - Table 6C. Panel A
* Column 6
reg winner_coalGOLKAR i.appyr_predec $controlset_predir early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) bdec(3) nocons keep(i.appyr_predec)

* Appendix B - Table 6E. Panel A
* Column 6
reg z_score i.appyr_predec $controlset_predir early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6E.xls", adds(Mean, `mean') ctitle(z_score, Col 6) bdec(3) nocons keep(i.appyr_predec)


global controlset_direl ltot_rev_pc_direl ltot_loc_rev_pc_direl

* Appendix B - Table 5B. Panel A
* Column 8
reg soeharto_elite appyr_predec $controlset_direl early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(soeharto_elite) bdec(3) nocons keep(appyr_predec)

* Appendix B - Table 6B. Panel B
* Column 8
reg soeharto_elite i.appyr_predec $controlset_direl early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6B.xls", adds(Mean, `mean') ctitle(soeharto_elite) bdec(3) nocons keep(i.appyr_predec)

* Appendix B - Table 5B. Panel B
* Column 8
reg winner_coalGOLKAR appyr_predec $controlset_direl early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) bdec(3) nocons keep(appyr_predec)

* Appendix B - Table 5C. Panel C
* Column 8
reg z_score appyr_predec $controlset_direl early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5C.xls", adds(Mean, `mean') ctitle(z_score) bdec(3) nocons keep(appyr_predec)

* Appendix B - Table 6C. Panel A
* Column 8
reg winner_coalGOLKAR i.appyr_predec $controlset_direl early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) bdec(3) nocons keep(i.appyr_predec)

* Appendix B - Table 6E. Panel A
* Column 8	
reg z_score i.appyr_predec $controlset_direl early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6E.xls", adds(Mean, `mean') ctitle(z_score, Col 8) bdec(3) nocons keep(i.appyr_predec)


* Appendix B - Table 5B. Panel A
* Column 7	
reg soeharto_elite appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6B. Panel B
* Column 7	
reg soeharto_elite i.appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(i.appyr_predec)

* Appendix B - Table 5B. Panel B
* Column 7	
reg winner_coalGOLKAR appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 5C. Panel C
* Column 7	
reg z_score appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5C.xls", adds(Mean, `mean') ctitle(z_score) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6C. Panel A
* Column 7	
reg winner_coalGOLKAR i.appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(i.appyr_predec)

* Appendix B - Table 6E. Panel A
* Column 7	
reg z_score i.appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6E.xls", adds(Mean, `mean') ctitle(z_score, Col 7) nocons bdec(3) keep(i.appyr_predec)



* Appendix B - Table 5B. Panel A
* Column 9
reg soeharto_elite appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6B. Panel A
* Column 9
reg soeharto_elite i.appyr_predec pilk_yr_dum05-pilk_yr_dum07p  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(i.appyr_predec)

* Appendix B - Table 5B. Panel B
* Column 9
reg winner_coalGOLKAR appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 5C. Panel C
* Column 9
reg z_score appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5C.xls", adds(Mean, `mean') ctitle(z_score) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6C. Panel A
* Column 9
reg winner_coalGOLKAR i.appyr_predec pilk_yr_dum05-pilk_yr_dum07p  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(i.appyr_predec)

* Appendix B - Table 6E. Panel A
* Column 9
reg z_score i.appyr_predec pilk_yr_dum05-pilk_yr_dum07p  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6E.xls", adds(Mean, `mean') ctitle(z_score, Col 9) nocons bdec(3) keep(i.appyr_predec)


* Appendix B - Table 5B. Panel A
* Column 10
reg soeharto_elite appyr_predec i.bup_experience early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6B. Panel B
* Column 10
reg soeharto_elite i.appyr_predec i.bup_experience early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6B.xls", adds(Mean, `mean') ctitle(soeharto_elite) nocons bdec(3) keep(i.appyr_predec)

* Appendix B - Table 5B. Panel B
* Column 10
reg winner_coalGOLKAR appyr_predec i.bup_experience early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5B.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 5C. Panel C
* Column 10
reg z_score appyr_predec i.bup_experience early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT5C.xls", adds(Mean, `mean') ctitle(z_score) nocons bdec(3) keep(appyr_predec)

* Appendix B - Table 6C. Panel A
* Column 10
reg winner_coalGOLKAR i.appyr_predec i.bup_experience early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR) nocons bdec(3) keep(i.appyr_predec)

* Appendix B - Table 6E. Panel A
* Column 10
reg z_score i.appyr_predec i.bup_experience early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT6E.xls", adds(Mean, `mean') ctitle(z_score, Col 10) nocons bdec(3) keep(i.appyr_predec)






******************************************************************************************************
** Appendix B - Table 5B. Panel C & Table 5C. Panel A, B & Table 6C. Panel B & Table 6D. Panel A, B **
******************************************************************************************************

capture erase "BT6D.xls"
capture erase "BT6D.txt"
	
use "DataBupati_PODES_2005.dta", clear			

* Appendix B - Table 5B. Panel C
* Column 2		
	reg GolkarFirst appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop* if appyr_predec!=1997, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5B.xls", bdec(3) nocons ctitle(GolkarFirst, AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predec)
	
* Appendix B - Table 6C. Panel B
* Column 2
	reg GolkarFirst i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop* if appyr_predec!=1997, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6C.xls", bdec(3) nocons ctitle(GolkarFirst,AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)

global controlset_predec incidents_appyr_predec totkil_appyr_predec totinj_appyr_predec

* Appendix B - Table 5B. Panel C
* Column 3		
	reg GolkarFirst appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5B.xls", bdec(3) nocons ctitle(GolkarFirst, AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predec)
			
* Appendix B - Table 6C. Panel B
* Column 3			
	reg  GolkarFirst i.appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6C.xls", bdec(3) nocons ctitle(GolkarFirst,AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
	
		
global controlset_predir incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir
	
* Appendix B - Table 5B. Panel C
* Column 5	 		
	reg  GolkarFirst appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5B.xls", bdec(3) nocons ctitle(GolkarFirst, AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predec)

		
* Appendix B - Table 6C. Panel B
* Column 5		 
	reg GolkarFirst i.appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6C.xls", bdec(3) nocons ctitle(GolkarFirst,AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
		

* Appendix B - Table 5B. Panel C
* Column 7			
	reg GolkarFirst appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5B.xls", bdec(3) nocons ctitle(GolkarFirst, AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predec)

		
* Appendix B - Table 6C. Panel B
* Column 7
	reg GolkarFirst i.appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6C.xls", bdec(3) nocons ctitle(GolkarFirst,AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
				
				
global controlset_predec ltot_rev_pc_predec ltot_loc_rev_pc_predec

* Appendix B - Table 5B. Panel C
* Column 4 		
	reg GolkarFirst appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5B.xls", bdec(3) nocons ctitle(GolkarFirst, AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predec)
			
		
* Appendix B - Table 6C. Panel B
* Column 4
	reg GolkarFirst i.appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6C.xls", bdec(3) nocons ctitle(GolkarFirst,AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
		

global controlset_predir ltot_rev_pc_predir ltot_loc_rev_pc_predir

* Appendix B - Table 5B. Panel C
* Column 6	
	reg GolkarFirst appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5B.xls", bdec(3) nocons ctitle(GolkarFirst, AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predec)
		
		
* Appendix B - Table 6C. Panel B
* Column 6
	reg GolkarFirst i.appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6C.xls", bdec(3) nocons ctitle(GolkarFirst,AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
		

global controlset_direl ltot_rev_pc_direl ltot_loc_rev_pc_direl

* Appendix B - Table 5B. Panel C
* Column 8		
	reg GolkarFirst appyr_predec $controlset_direl gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5B.xls", bdec(3) nocons ctitle(GolkarFirst, AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predec)
		
		
* Appendix B - Table 6C. Panel B
* Column 8
	reg GolkarFirst i.appyr_predec $controlset_direl gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6C.xls", bdec(3) nocons ctitle(GolkarFirst,AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
		
* Appendix B - Table 5B. Panel C
* Column 9 		
	reg GolkarFirst appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5B.xls", bdec(3) nocons ctitle(GolkarFirst, AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predec)
			
		
* Appendix B - Table 6C. Panel B
* Column 9
	reg GolkarFirst i.appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6C.xls", bdec(3) nocons ctitle(GolkarFirst,AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
	
	
* Appendix B - Table 5B. Panel C
* Column 10		
	reg GolkarFirst appyr_predec i.bup_experience gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5B.xls", bdec(3) nocons ctitle(GolkarFirst, AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predec)
			
		
* Appendix B - Table 6C. Panel B
* Column 10
	reg GolkarFirst i.appyr_predec i.bup_experience gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6C.xls", bdec(3) nocons ctitle(GolkarFirst,AllContr) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
		
	

		
		
	
use "DataBupati_Election_2004.dta", clear			

* Appendix B - Table 5C. Panel A
* Column 2
	reg  gol_2004_perc appyr_predec gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)

* Appendix B - Table 6D. Panel A
* Column 2
	reg gol_2004_perc i.appyr_predec gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)

	
global controlset_predec incidents_appyr_predec totkil_appyr_predec totinj_appyr_predec

* Appendix B - Table 5C. Panel A
* Column 3	
	reg  gol_2004_perc appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		

* Appendix B - Table 6D. Panel A
* Column 3	
	reg gol_2004_perc i.appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
		
		

global controlset_predir incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir

* Appendix B - Table 5C. Panel A
* Column 5	
	reg gol_2004_perc appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		

* Appendix B - Table 6D. Panel A
* Column 5	
	reg gol_2004_perc i.appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
	

* Appendix B - Table 5C. Panel A
* Column 7
	reg gol_2004_perc appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel A
* Column 7
	reg gol_2004_perc i.appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)


global controlset_predec ltot_rev_pc_predec ltot_loc_rev_pc_predec
	
* Appendix B - Table 5C. Panel A
* Column 4
	reg gol_2004_perc appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel A
* Column 4
	reg gol_2004_perc i.appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)


global controlset_predir ltot_rev_pc_predir ltot_loc_rev_pc_predir

* Appendix B - Table 5C. Panel A
* Column 6
	reg gol_2004_perc appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel A
* Column 6
	reg gol_2004_perc i.appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
				

global controlset_direl ltot_rev_pc_direl ltot_loc_rev_pc_direl

* Appendix B - Table 5C. Panel A
* Column 8
	reg gol_2004_perc appyr_predec $controlset_direl gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel A
* Column 8
	reg gol_2004_perc i.appyr_predec $controlset_direl gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
	

* Appendix B - Table 5C. Panel A
* Column 9
	reg gol_2004_perc appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel A
* Column 9
	reg gol_2004_perc i.appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
		
* Appendix B - Table 5C. Panel A
* Column 10	
	reg gol_2004_perc appyr_predec i.bup_experience gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix Table 6D. Panel A
* Column 10		
	reg gol_2004_perc i.appyr_predec i.bup_experience gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2004_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
		
	
		

use "DataBupati_Election_2009.dta", clear

* Appendix B - Table 5C. Panel B
* Column 2
	reg  gol_2009_perc appyr_predec gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)


* Appendix B - Table 6D. Panel B
* Column 2		
	reg  gol_2009_perc i.appyr_predec gol_1992_perc pdi_1992_perc isdum* if appyr_predec!=1997, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)

	
global controlset_predec incidents_appyr_predec totkil_appyr_predec totinj_appyr_predec

* Appendix Table 5C. Panel B
* Column 3	
	reg gol_2009_perc appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		

* Appendix Table 6D. Panel B
* Column 3		
	reg gol_2009_perc i.appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)


global controlset_predir incidents_appyr_predir totkil_appyr_predir totinj_appyr_predir

* Appendix Table 9C. Panel B
* Column 5
	reg gol_2009_perc appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)


* Appendix Table 10D. Panel B
* Column 5		
	reg gol_2009_perc i.appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
		

* Appendix B - Table 5C. Panel B
* Column 7
	reg gol_2009_perc appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel B
* Column 7	
	reg gol_2009_perc i.appyr_predec conflict_direl gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
		
		
		
global controlset_predec ltot_rev_pc_predec ltot_loc_rev_pc_predec

* Appendix B - Table 5C. Panel B
* Column 4
	reg gol_2009_perc appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel B
* Column 4
	reg gol_2009_perc i.appyr_predec $controlset_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
		

global controlset_predir ltot_rev_pc_predir ltot_loc_rev_pc_predir

* Appendix B - Table 5C. Panel B
* Column 6
	reg gol_2009_perc appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel B
* Column 6	
	reg gol_2009_perc i.appyr_predec $controlset_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
		

global controlset_direl ltot_rev_pc_direl ltot_loc_rev_pc_direl

* Appendix B - Table 5C. Panel B
* Column 8
	reg gol_2009_perc appyr_predec $controlset_direl gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel B
* Column 8
	reg gol_2009_perc i.appyr_predec $controlset_direl gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
		

* Appendix B - Table 5C. Panel B
* Column 9
	reg gol_2009_perc appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix B - Table 6D. Panel B
* Column 9
	reg gol_2009_perc i.appyr_predec pilk_yr_dum05-pilk_yr_dum07p gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
				
* Appendix Table 5C. Panel B
* Column 10	
	reg gol_2009_perc appyr_predec i.bup_experience gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT5C.xls", bdec(3) nocons  ///
		ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predec)
		
* Appendix Table 6D. Panel B
* Column 10	
	reg gol_2009_perc i.appyr_predec i.bup_experience gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT6D.xls", bdec(3) nocons ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predec)
			
		


		
	
************************************************************************************* 
** Appendix B - Table 7 Reelection Rates of District Mayors by Year of Appointment ** 
************************************************************************************* 
use "DataBupati_Appointments.dta", clear

keep if num_splits==1 & gol_1992_perc!=.

tab appyr_predec
tab appyr_predec reelect_dum
tab appyr_predec, sum(reelect_dum)		
	
		

*****************************************************************************************
** Appendix B - Table 8 Baseline Results Including Districts with Appointments in 1998 **
*****************************************************************************************		

use "DataBupati_EGI_ext.dta", clear
 
capture erase  "BT8.xls"
capture erase  "BT8.txt"

* Column 1
reg bribe_AP i.appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT8.xls", bdec(3) nocons ctitle(bribe_AP) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
	drop esample temp
	
* Column 2 & 3

use "DataBupati_PODES_ext.dta", clear	

foreach var in z_score_edu z_score_health {
	areg  `var' appyr_predec##post_dum lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT8.xls", bdec(3) nocons keep(1995.appyr_predec#1.post_dum 1996.appyr_predec#1.post_dum 1997.appyr_predec#1.post_dum 1998.appyr_predec#1.post_dum 1.post_dum) ///
	ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	}

* Column 4	
	
use "DataBupati_Backgrounds_ext.dta", clear

reg soeharto_elite i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT8.xls", keep(i.appyr_predec) adds(Mean, `mean') ctitle(soeharto_elite) nocons

* Columns 5 & 7

foreach var of varlist winner_coalGOLKAR z_score {
reg `var' i.appyr_predec early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT8.xls", adds(Mean, `mean') ctitle(`var') nocons bdec(3) keep(i.appyr_predec)
}

* Column 6
use "DataBupati_PODES_2005_ext.dta", clear			

	reg  GolkarFirst i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 dum_95-dum_97 gol_1992_perc pdi_1992_perc using "BT8.xls", bdec(3) nocons ctitle(GolkarFirst) ///
	adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predec)
	

*********************************************************************
** Appendix B - Table 9. Appointment Timing and District Splitting **
*********************************************************************

capture erase "BT9.xls"
capture erase "BT9.txt"

use "DataBupati_Split.dta", clear

* Column 1
reg split appyr_predec, robust
gen esample=e(sample)
sum split if esample==1
drop esample
outreg2 using "BT9.xls", keep(appyr_predec) bdec(3) nocons ctitle(FullSamp) 

* Column 2
reg split i.appyr_predec, robust
outreg2  using "BT9.xls", keep(1995.appyr_predec 1996.appyr_predec 1997.appyr_predec 1998.appyr_predec) bdec(3) nocons ctitle(FullSamp)

* Column 3
reg split appyr_predec if appyr_predec!=1998, robust
outreg2 appyr_predec using "BT9.xls", keep(appyr_predec) bdec(3) nocons ctitle(Drop98)

* Column 4
reg split i.appyr_predec if appyr_predec!=1998, robust
gen esample=e(sample)
sum split if esample==1
drop esample
outreg2  using "BT9.xls", keep(1995.appyr_predec 1996.appyr_predec 1997.appyr_predec) bdec(3) nocons ctitle(Drop98)
				
		
*****************************************		
** Robustness Check District Splitting **
*****************************************	

capture erase "BT10.xls"
capture erase "BT10.txt"	
	
use "DataBupati_Split.dta", clear

#delimit ;
global predeterm_vars_PODES lpopulation_1993 popdensity_1993 rel_frag_1993 ethnic_frag_2003 
num_pri_ph num_hs_ph num_kindgarden_ph
num_puskesmas_ph num_doctors_ph num_midwives_ph tba_dum;
#delimit cr

#delimit ;
global predeterm_vars_politics  
gol_1992_perc pdi_1992_perc 
incidents_avg_90_93 prev_term_length
herf_1992 
ltot_rev_pc_1994 ltot_loc_rev_pc_1994 ;
#delimit cr

gen appyr_predec_old=appyr_predec
drop appyr_predec
gen appyr_predec=appyr_predec_old-1994

drop if appyr_predec_old==1998

foreach var of varlist $predeterm_vars_PODES $predeterm_vars_politics {

reg `var' c.appyr_predec##c.split, robust
outreg2 using "BT10.xls", keep(split appyr_predec c.appyr_predec#c.split) bdec(3) nocons ctitle(`var') 
}	



** Appendix B - Table 11A. Robustness Check to Using End of Term of Soeharto Mayors
* For the reduced form results, please refer to the respective baseline estimates

capture erase "BT11A.xls"
capture erase "BT11A.txt"

use "DataBupati_EGI.dta", clear

* Panel A. Column 2
reg bribe_AP appyr_predir gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(bribe_AP, OLS) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predir)
	drop esample temp
	

	


* Panel B. Column 5 & Panel C. Column 8
use "DataBupati_PODES_Panel.dta", clear	
 	
foreach var in z_score_edu z_score_health {
	areg  `var' c.appyr_predir##post_dum lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(`var', OLS) adds(Mean, `mean', clust, e(N_clust)) keep(c.appyr_predir##post_dum)
	}
	
	
	
use "DataBupati_Backgrounds.dta", clear

* Panel D. Column 2

reg soeharto_elite appyr_predir early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, cluster(id_district)
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT11A.xls", adds(Mean, `mean') ctitle(soeharto_elite, OLS) nocons bdec(3) keep(appyr_predir)

* Panel E. Column 5 & Panel I. Column 8

foreach var of varlist winner_coalGOLKAR z_score {

reg `var' appyr_predir early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, cluster(id_district)
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT11A.xls", adds(Mean, `mean') ctitle(`var', OLS) nocons bdec(3) keep(appyr_predir)
}

	
* Panel F. Column 8	
use "DataBupati_PODES_2005.dta", clear			
		
	reg GolkarFirst appyr_predir gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(GolkarFirst, OLS) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(appyr_predir)

			
* Panel G. Column 2				
use "DataBupati_Election_2004.dta", clear			

	reg gol_2004_perc appyr_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(gol_2004_perc, OLS) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predir)
	



* Panel H. Column 5
use "DataBupati_Election_2009.dta", clear

	reg gol_2009_perc appyr_predir gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(gol_2009_perc, OLS) adds(Mean, `mean', NumKabs, `numkab') keep(appyr_predir)
	
	
	

* Panel A. Column 3
use "DataBupati_EGI.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

	ivreg2 bribe_AP gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first (appyr_predir_adj=appyr_predec), cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	local kleibergen_paap_fstat=e(widstat)	
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(bribe_AP, IV) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') keep(appyr_predir_adj)
	drop esample temp
	


* Panel B. Column 6 & Panel C. Column 9	

use "DataBupati_PODES_Panel.dta", clear	
  
gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004
 	
gen end_interaction=post_dum*appyr_predir_adj
gen ex_interaction=post_dum*appyr_predec

foreach var in z_score_edu z_score_health {
	ivreg2 `var' lpop* podes_yr* i.id_district (end_interaction=ex_interaction), cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	local kleibergen_paap_fstat=e(widstat)		
	drop esample
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(`var', IV) adds(Mean, `mean', clust, e(N_clust), Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') keep(end_interaction)
	}
	
	
	


use "DataBupati_Backgrounds.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

* Panel D. Column 3

ivreg2 soeharto_elite early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum* (appyr_predir_adj=appyr_predec), cluster(id_district)
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
local kleibergen_paap_fstat=e(widstat)
drop esample
outreg2 using "BT11A.xls", adds(Mean, `mean', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') ctitle(soeharto_elite, IV) nocons keep(appyr_predir_adj)

* Panel E. Column 6 & Panel I. Column 9
foreach var of varlist winner_coalGOLKAR z_score {
ivreg2 `var' early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum* (appyr_predir_adj=appyr_predec), cluster(id_district)
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
local kleibergen_paap_fstat=e(widstat)
drop esample
outreg2 using "BT11A.xls", adds(Mean, `mean', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') ctitle(`var', IV) nocons keep(appyr_predir_adj)
}


* Panel F. Column 9 	
use "DataBupati_PODES_2005.dta", clear			

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004
 			
	ivreg2 GolkarFirst gol_1992_perc pdi_1992_perc isdum* lpop* (appyr_predir_adj=appyr_predec), cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	local kleibergen_paap_fstat=e(widstat)	
	drop esample temp
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(GolkarFirst, IV) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') keep(appyr_predir_adj)
		

* Panel G. Column 3

use "DataBupati_Election_2004.dta", clear			

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004
		
	ivreg2 gol_2004_perc gol_1992_perc pdi_1992_perc isdum* (appyr_predir_adj=appyr_predec), robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	local kleibergen_paap_fstat=e(widstat)	
	drop esample temp
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(`var', IV) adds(Mean, `mean', NumKabs, `numkab', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') keep(appyr_predir_adj)
		
		

* Panel H. Column 6	

use "DataBupati_Election_2009.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

	ivreg2 gol_2009_perc gol_1992_perc pdi_1992_perc isdum* (appyr_predir_adj=appyr_predec), robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	local kleibergen_paap_fstat=e(widstat)		
	drop esample temp
	outreg2 using "BT11A.xls", bdec(3) nocons ctitle(gol_2009_perc, IV) adds(Mean, `mean', NumKabs, `numkab', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat')
		
		
		
**************************************************************************************		
** Appendix B - Table 11B Robustness Check to Using End of Term of Soeharto Mayors **
**************************************************************************************

capture erase  "BT11B.xls"
capture erase  "BT11B.txt"

* Panel A. Colummn 2
use "DataBupati_EGI.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

reg bribe_AP i.appyr_predir_adj gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT11B.xls", bdec(3) nocons ctitle(bribe_AP) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predir_adj)
	drop esample temp



* Panel B. Column 5 & Panel C. Column 8 	

use "DataBupati_PODES_Panel.dta", clear	
  
gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

foreach var in z_score_edu z_score_health {
	areg  `var' appyr_predir_adj##post_dum gol_1992_perc pdi_1992_perc isdum* lpop* podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT11B.xls", bdec(3) nocons ctitle(`var', OLS) adds(Mean, `mean', clust, e(N_clust))
	}		
	


* Panel A. Colummn 3
use "DataBupati_EGI.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

	ivreg2 bribe_AP gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first (i.appyr_predir_adj=i.appyr_predec), cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	local kleibergen_paap_fstat=e(widstat)	
	outreg2 using "BT11B.xls", bdec(3) nocons ctitle(bribe_AP, IV) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') keep(i.appyr_predir_adj)
	drop esample temp
	

* Panel B. Column 6 & Panel C. Column 9 	
use "DataBupati_PODES_Panel.dta", clear	
	
gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004
	
gen appyr_predir_dum_99=(appyr_predir_adj==1999)
gen appyr_predir_dum_00=(appyr_predir_adj==2000)
gen appyr_predir_dum_01=(appyr_predir_adj==2001)
gen appyr_predir_dum_02=(appyr_predir_adj==2002)

gen appyr_predec_dum_94=(appyr_predec==1994)
gen appyr_predec_dum_95=(appyr_predec==1995)
gen appyr_predec_dum_96=(appyr_predec==1996)
gen appyr_predec_dum_97=(appyr_predec==1997)

gen end_interaction_99=post_dum*appyr_predir_dum_99
gen end_interaction_00=post_dum*appyr_predir_dum_00
gen end_interaction_01=post_dum*appyr_predir_dum_01
gen end_interaction_02=post_dum*appyr_predir_dum_02

gen ex_interaction_94=post_dum*appyr_predec_dum_94
gen ex_interaction_95=post_dum*appyr_predec_dum_95
gen ex_interaction_96=post_dum*appyr_predec_dum_96
gen ex_interaction_97=post_dum*appyr_predec_dum_97
	
foreach var in z_score_edu z_score_health {
	ivreg2 `var' lpop* podes_yr* i.id_district (end_interaction_00-end_interaction_02=ex_interaction_95-ex_interaction_97), cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	local kleibergen_paap_fstat=e(widstat)		
	drop esample
	outreg2 using "BT11B.xls", bdec(3) nocons ctitle(`var', IV) keep(end_interaction_00-end_interaction_02) adds(Mean, `mean', clust, e(N_clust), Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat')
	}

	
	
	
*************************************************************************************
** Appendix B - Table 11C Robustness Check to Using End of Term of Soeharto Mayors **
*************************************************************************************

capture erase  "BT11C.xls"
capture erase  "BT11C.txt"

use "DataBupati_Backgrounds.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

* Panel A. Column 2
reg soeharto_elite i.appyr_predir_adj early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, cluster(id_district)
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT11C.xls", adds(Mean, `mean') ctitle(soeharto_elite, OLS) nocons bdec(3) keep(i.appyr_predir_adj)


* Panel B. Column 5
reg winner_coalGOLKAR i.appyr_predir_adj early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, cluster(id_district)
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT11C.xls", adds(Mean, `mean') ctitle(winner_coalGOLKAR, OLS) nocons bdec(3) keep(i.appyr_predir_adj)


*Panel C. Column 8	
use "DataBupati_PODES_2005.dta", clear			

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

	reg GolkarFirst i.appyr_predir_adj gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT11C.xls", bdec(3) nocons ctitle(GolkarFirst, OLS) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab') keep(i.appyr_predir_adj)
		



use "DataBupati_Backgrounds.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

* Panel A. Column 3
ivreg2 soeharto_elite early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum* (i.appyr_predir_adj=i.appyr_predec), cluster(id_district)
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
local kleibergen_paap_fstat=e(widstat)
drop esample
outreg2 using "BT11C.xls", adds(Mean, `mean', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') ctitle(soeharto_elite, IV) nocons keep(i.appyr_predir_adj)


* Panel B. Column 6
ivreg2 winner_coalGOLKAR early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum* (i.appyr_predir_adj=i.appyr_predec), cluster(id_district)
gen esample=e(sample)
sum winner_coalGOLKAR if esample==1
local mean=r(mean)
local kleibergen_paap_fstat=e(widstat)
drop esample
outreg2 using "BT11C.xls", adds(Mean, `mean', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') ctitle(winner_coalGOLKAR, IV) nocons


use "DataBupati_PODES_2005.dta", clear		

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

* Panel C. Column 9 
	ivreg2 GolkarFirst gol_1992_perc pdi_1992_perc isdum* lpop* (i.appyr_predir_adj=i.appyr_predec), cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	local kleibergen_paap_fstat=e(widstat)	
	drop esample temp
	outreg2 using "BT11C.xls", bdec(3) nocons ctitle(GolkarFirst, IV) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') keep(i.appyr_predir_adj)
			

*************************************************************************************	
** Appendix B - Table 11D Robustness Check to Using End of Term of Soeharto Mayors **
*************************************************************************************

capture erase  "BT11D.xls"
capture erase  "BT11D.txt"

*Panel A. Column 2	
use "DataBupati_Election_2004.dta", clear			

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

	reg gol_2004_perc i.appyr_predir_adj gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT11D.xls", bdec(3) nocons  ctitle(gol_2004_perc, OLS) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predir_adj)
	



* Panel B. Column 5
use "DataBupati_Election_2009.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

	reg gol_2009_perc i.appyr_predir_adj gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT11D.xls", bdec(3) nocons ctitle(gol_2009_perc, OLS) adds(Mean, `mean', NumKabs, `numkab') keep(i.appyr_predir_adj)
				

* Panel C. Column 8		
use "DataBupati_Backgrounds.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

reg z_score i.appyr_predir_adj early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, cluster(id_district)
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT11D.xls", adds(Mean, `mean') ctitle(z_score, OLS) nocons bdec(3) keep(i.appyr_predir_adj)
		


*Panel A. Column 3	
use "DataBupati_Election_2004.dta", clear			

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

	ivreg2 gol_2004_perc gol_1992_perc pdi_1992_perc isdum* (i.appyr_predir_adj=i.appyr_predec), robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	local kleibergen_paap_fstat=e(widstat)	
	drop esample temp
	outreg2 using "BT11D.xls", bdec(3) nocons ctitle(gol_2004_perc, IV) adds(Mean, `mean', NumKabs, `numkab', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') keep(i.appyr_predir_adj)

		

* Panel B. Column 6
use "DataBupati_Election_2009.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

	ivreg2 gol_2009_perc gol_1992_perc pdi_1992_perc isdum* (i.appyr_predir_adj=i.appyr_predec), robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	local kleibergen_paap_fstat=e(widstat)		
	drop esample temp
	outreg2 using "BT11D.xls", bdec(3) nocons ctitle(gol_2009_perc, IV) adds(Mean, `mean', NumKabs, `numkab', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') keep(i.appyr_predir_adj)
		

* Panel C. Column 9	
use "DataBupati_Backgrounds.dta", clear

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

ivreg2 z_score early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum* (i.appyr_predir_adj=i.appyr_predec), cluster(id_district)
gen esample=e(sample)
sum z_score if esample==1
local mean=r(mean)
local kleibergen_paap_fstat=e(widstat)
drop esample
outreg2 using "BT11D.xls", bdec(3) nocons ctitle(z_score, IV) adds(Mean, `mean', Kleibergen-Paap F-Statistic, `kleibergen_paap_fstat') keep(i.appyr_predir_adj)




***************************************************************************************************
** Appendix B - Table 11E Robustness Check to Using End of Term of Soeharto Mayors (First Stage) **
***************************************************************************************************

capture erase  "BT11E.xls"
capture erase  "BT11E.txt"

use "DataBupati_Appointments.dta", clear

keep if gol_1992_perc!=. & num_splits==1 & appyr_predec!=1998

gen appyr_predir_adj=appyr_predir
replace appyr_predir_adj=2002 if appyr_predir==2003|appyr_predir==2004

tab appyr_predec, gen(dec)
tab appyr_predir_adj, gen(dir)

gen ay_predec=appyr_predec
gen ay_predir=appyr_predir
	

* Column 1

reg appyr_predir appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
outreg2 using "BT11E.xls", bdec(3)

* Columns 2-4

reg dir2 dec2 dec3 dec4 gol_1992_perc pdi_1992_perc isdum*, robust
outreg2 using "BT11E.xls", bdec(3)

reg dir3 dec2 dec3 dec4 gol_1992_perc pdi_1992_perc isdum*, robust
outreg2 using "BT11E.xls", bdec(3)

reg dir4 dec2 dec3 dec4 gol_1992_perc pdi_1992_perc isdum*, robust
outreg2 using "BT11E.xls", bdec(3)
		
		
		
		
		
***************************************************************************************************************************
** Appendix B - Table 12A Local Transfers from Central Government and Exposure to Soeharto Mayors (Linear Specification) **
***************************************************************************************************************************		
		
capture erase  "BT12A.xls"
capture erase  "BT12A.txt"

use "DataBupati_LocalBudgets.dta", clear

* Panel A. Fiscal Year 1999

* Columns 1, 4, 5, 6 
foreach var of varlist tot_provision_rev_pc_1999 provision_notax_share_pc_1999 provision_tax_share_pc_1999 tot_provision_rev_ex_tax_pc_1999 {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT12A.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 1999) adds(Mean, `mean', NumKabs, `numkab')
	}

* Panel B. Fiscal Year 2000

* Columns 1, 4, 5, 6
foreach var of varlist tot_provision_rev_pc_2000 provision_notax_share_pc_2000 provision_tax_share_pc_2000 tot_provision_rev_ex_tax_pc_2000  {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT12A.xls", bdec(3) nocons  ///
	keep(appyr_predec) ///
	ctitle(`var', 2000) adds(Mean, `mean', NumKabs, `numkab')
	}

* Panel C. Fiscal Year 2001

* Columns 1 to 6 
foreach var of varlist cent_gov_trans_pc_2001 cent_gov_trans_dau_pc_2001 cent_gov_trans_dak_pc_2001 cent_gov_trans_sda_pc_2001 cent_gov_trans_tax_pc_2001 cent_gov_trans_ex_tax_pc_2001 {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT12A.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2001) adds(Mean, `mean', NumKabs, `numkab')
	}

* Panel D. Fiscal Year 2002

* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2002 cent_gov_trans_dau_pc_2002 cent_gov_trans_dak_pc_2002 cent_gov_trans_sda_pc_2002 cent_gov_trans_tax_pc_2002 cent_gov_trans_ex_tax_pc_2002 {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT12A.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2002) adds(Mean, `mean', NumKabs, `numkab')
	}
	
* Panel E. Fiscal Year 2003

* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2003 cent_gov_trans_dau_pc_2003 cent_gov_trans_dak_pc_2003 cent_gov_trans_sda_pc_2003 cent_gov_trans_tax_pc_2003 cent_gov_trans_ex_tax_pc_2003 {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT12A.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2003) adds(Mean, `mean', NumKabs, `numkab')
	}
	
		
		
	
***************************************************************************************************************************
** Appendix B - Table 12B Local Transfers from Central Government and Exposure to Soeharto Mayors (Linear Specification) **
***************************************************************************************************************************

capture erase  "BT12B.xls"
capture erase  "BT12B.txt"		
		
use "DataBupati_LocalBudgets.dta", clear		

* Panel A. Fiscal Year 2004

* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2004 cent_gov_trans_dau_pc_2004 cent_gov_trans_dak_pc_2004 cent_gov_trans_sda_pc_2004 cent_gov_trans_tax_pc_2004 cent_gov_trans_ex_tax_pc_2004 {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT12B.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2004) adds(Mean, `mean', NumKabs, `numkab')
		}

* Panel B. Fiscal Year 2005

* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2005 cent_gov_trans_dau_pc_2005 cent_gov_trans_dak_pc_2005 cent_gov_trans_sda_pc_2005 cent_gov_trans_tax_pc_2005 cent_gov_trans_ex_tax_pc_2005 {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT12B.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2005) adds(Mean, `mean', NumKabs, `numkab')
	}
		
* Panel C. Fiscal Year 2006

* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2006 cent_gov_trans_dau_pc_2006 cent_gov_trans_dak_pc_2006 cent_gov_trans_sda_pc_2006 cent_gov_trans_tax_pc_2006 cent_gov_trans_ex_tax_pc_2006 {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT12B.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2006) adds(Mean, `mean', NumKabs, `numkab')
	}	
		
* Panel D. Fiscal Year 2007

* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2007 cent_gov_trans_dau_pc_2007 cent_gov_trans_dak_pc_2007 cent_gov_trans_sda_pc_2007 cent_gov_trans_tax_pc_2007 cent_gov_trans_ex_tax_pc_2007 {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT12B.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2007) adds(Mean, `mean', NumKabs, `numkab')
	}
		
		
*****************************************************************************************************************************		
** Appendix B - Table 13A Local Transfers from Central Government and Exposure to Soeharto Mayors (Flexible Specification) **
*****************************************************************************************************************************		
		

capture erase  "BT13A.xls"
capture erase  "BT13A.txt"			
		
use "DataBupati_LocalBudgets.dta", clear

* Panel A. Fiscal Year 1999
		
* Columns 1, 4, 5, 6
foreach var of varlist tot_provision_rev_pc_1999 provision_notax_share_pc_1999 provision_tax_share_pc_1999 tot_provision_rev_ex_tax_pc_1999 {
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT13A.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 1999) adds(Mean, `mean', NumKabs, `numkab')
	}		

* Panel B. Fiscal Year 2000
	
* Columns 1, 4, 5, 6
foreach var of varlist tot_provision_rev_pc_2000 provision_notax_share_pc_2000 provision_tax_share_pc_2000 provision_tax_share_pc_2000 tot_provision_rev_ex_tax_pc_2000 {
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT13A.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2000) adds(Mean, `mean', NumKabs, `numkab')
	}			

* Panel C. Fiscal Year 2001
		
* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2001 cent_gov_trans_dau_pc_2001 cent_gov_trans_dak_pc_2001 cent_gov_trans_sda_pc_2001 cent_gov_trans_tax_pc_2001 cent_gov_trans_ex_tax_pc_2001 {
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT13A.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2001) adds(Mean, `mean', NumKabs, `numkab')
	}		


	
	
*****************************************************************************************************************************	
** Appendix B - Table 13B Local Transfers from Central Government and Exposure to Soeharto Mayors (Flexible Specification) **
***************************************************************************************************************************** 
	
capture erase  "BT13B.xls"
capture erase  "BT13B.txt"		
	
use "DataBupati_LocalBudgets.dta", clear

* Panel A. Fiscal Year 2002

* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2002 cent_gov_trans_dau_pc_2002 cent_gov_trans_dak_pc_2002 cent_gov_trans_sda_pc_2002 cent_gov_trans_tax_pc_2002 cent_gov_trans_ex_tax_pc_2002 {
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT13B.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2002) adds(Mean, `mean', NumKabs, `numkab')
		}		

* Panel B. Fiscal Year 2003

* Columns 1 to 6	
foreach var of varlist cent_gov_trans_pc_2003 cent_gov_trans_dau_pc_2003 cent_gov_trans_dak_pc_2003 cent_gov_trans_sda_pc_2003 cent_gov_trans_tax_pc_2003 cent_gov_trans_ex_tax_pc_2003 {
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT13B.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2003) adds(Mean, `mean', NumKabs, `numkab')
		}					
	
* Panel C. Fiscal Year 2004

* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2004 cent_gov_trans_dau_pc_2004 cent_gov_trans_dak_pc_2004 cent_gov_trans_sda_pc_2004 cent_gov_trans_tax_pc_2004 cent_gov_trans_ex_tax_pc_2004 {
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT13B.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2004) adds(Mean, `mean', NumKabs, `numkab')
	}				

	
	
	
*****************************************************************************************************************************	
** Appendix B - Table 13C Local Transfers from Central Government and Exposure to Soeharto Mayors (Flexible Specification) **
*****************************************************************************************************************************	
	
capture erase  "BT13C.xls"
capture erase  "BT13C.txt"		
	
* Panel A. Fiscal Year 2005

* Columns 1 to 6
foreach var of varlist cent_gov_trans_pc_2005 cent_gov_trans_dau_pc_2005 cent_gov_trans_dak_pc_2005 cent_gov_trans_sda_pc_2005 cent_gov_trans_tax_pc_2005 cent_gov_trans_ex_tax_pc_2005 {
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT13C.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2005) adds(Mean, `mean', NumKabs, `numkab')
	}			

* Panel B. Fiscal Year 2006		
		
* Columns 1 to 6	
foreach var of varlist cent_gov_trans_pc_2006 cent_gov_trans_dau_pc_2006 cent_gov_trans_dak_pc_2006 cent_gov_trans_sda_pc_2006 cent_gov_trans_tax_pc_2006 cent_gov_trans_ex_tax_pc_2006 {
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT13C.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2006) adds(Mean, `mean', NumKabs, `numkab')
	}		
		
* Panel C. Fiscal Year 2007
		
* Columns 1 to 6	
foreach var of varlist cent_gov_trans_pc_2007 cent_gov_trans_dau_pc_2007 cent_gov_trans_dak_pc_2007 cent_gov_trans_sda_pc_2007 cent_gov_trans_tax_pc_2007 cent_gov_trans_ex_tax_pc_2007 {
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT13C.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2007) adds(Mean, `mean', NumKabs, `numkab')
		}				
			
******************************************************************************************************		
** Appendix B - Table 14A Robustness Check: Controlling for Local Transfers from Central Government **
******************************************************************************************************

capture erase  "BT14A.xls"
capture erase  "BT14A.txt"
	
use "DataBupati_PODES_2011.dta", clear

foreach var in z_score_edu z_score_health z_score_services {
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop* cent_gov_trans_pc, cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT14A.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2011) adds(Mean, `mean', clust, e(N_clust))

	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop* cent_gov_trans_pc, cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT14A.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2011) adds(Mean, `mean', clust, e(N_clust))
	
	}


use "DataBupati_PODES_Panel.dta", clear		
	
foreach var in z_score_edu z_score_health z_score_services {
	areg  `var' c.appyr_predec##post_dum lpop* cent_gov_trans_pc podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT14A.xls", bdec(3) nocons  ///
		keep(c.appyr_predec##post_dum) ///
		ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
	
	areg  `var' appyr_predec##post_dum lpop* cent_gov_trans_pc podes_yr*, cluster(id_district) abs(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT14A.xls", bdec(3) nocons  ///
		keep(appyr_predec##post_dum) ///
		ctitle(`var', PANEL) adds(Mean, `mean', clust, e(N_clust))
		}
		
		
		
******************************************************************************************************
** Appendix B - Table 14B Robustness Check: Controlling for Local Transfers from Central Government **
******************************************************************************************************		

capture erase  "BT14B.xls"
capture erase  "BT14B.txt"	


use "DataBupati_EGI.dta", clear

* Column 1. Panel A
reg bribe_AP appyr_predec cent_gov_trans_pc_2007 gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT14B.xls", bdec(3) nocons ctitle(bribe_AP, Panel A) keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp

* Column 1. Panel B
reg bribe_AP i.appyr_predec cent_gov_trans_pc_2007 gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum* first, cluster(id_district)
	gen esample=e(sample)
	sum bribe_AP if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT14B.xls", bdec(3) nocons ctitle(bribe_AP, Panel B) keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	



use "DataBupati_Backgrounds.dta", clear

* Column 2. Panel A

reg soeharto_elite appyr_predec cent_gov_trans_pc early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT14B.xls", keep(appyr_predec) adds(Mean, `mean') ctitle(soeharto_elite, Panel A) nocons

* Column 2. Panel B

reg soeharto_elite i.appyr_predec cent_gov_trans_pc early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum soeharto_elite if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT14B.xls", keep(i.appyr_predec) adds(Mean, `mean') ctitle(soeharto_elite, Panel B) nocons

* Column 3. Panel A & Column 7. Panel A
foreach var of varlist winner_coalGOLKAR z_score {
reg `var' appyr_predec cent_gov_trans_pc early_pilk_dum05_06  gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT14B.xls", keep(appyr_predec) adds(Mean, `mean') ctitle(`var', Panel A) nocons

* Column 3. Panel B & Column 7. Panel B
reg `var' i.appyr_predec cent_gov_trans_pc early_pilk_dum05_06 gol_1992_perc pdi_1992_perc isdum*, robust
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT14B.xls", keep(i.appyr_predec) adds(Mean, `mean') ctitle(`var', Panel B) nocons		

}


	
use "DataBupati_PODES_2005.dta", clear			

* Column 4. Panel A				
	reg GolkarFirst appyr_predec cent_gov_trans_pc gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT14B.xls", bdec(3) nocons keep(appyr_predec) ctitle(GolkarFirst, Panel) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
			
		
* Column 4. Panel B 
	reg GolkarFirst i.appyr_predec cent_gov_trans_pc gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum GolkarFirst if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT14B.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(GolkarFirst, Panel B) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
		
		
		
use "DataBupati_Election_2004.dta", clear		

* Column 5. Panel A
	reg gol_2004_perc appyr_predec cent_gov_trans_pc gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 appyr_predec using "BT14B.xls", bdec(3) nocons keep(appyr_predec) ctitle(gol_2004_perc, Panel A) adds(Mean, `mean', NumKabs, `numkab')
	
	
* Column 5. Panel B
	reg gol_2004_perc i.appyr_predec cent_gov_trans_pc gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2004_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT14B.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(gol_2004_perc, Panel B) adds(Mean, `mean', NumKabs, `numkab')
		
		
use "DataBupati_Election_2009.dta", clear

* Column 6. Panel A
	reg gol_2009_perc appyr_predec cent_gov_trans_pc gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT14B.xls", bdec(3) nocons keep(appyr_predec) ctitle(gol_2009_perc, Panel A) adds(Mean, `mean', NumKabs, `numkab')
		
* Column 6. Panel B
	reg gol_2009_perc i.appyr_predec cent_gov_trans_pc gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum gol_2009_perc if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT14B.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(gol_2009_perc, AllContr) adds(Mean, `mean', NumKabs, `numkab')
		
		

****************************************************************************		
** Appendix B - Table 15 Federal Programs and Exposure to Soeharto Mayors **
****************************************************************************

capture erase  "BT15.xls"
capture erase  "BT15.txt"	

use "DataBupati_PODES_2003_Add.dta", clear

* Column 1. Panel A 
reg num_health_cards_2003_pc appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_health_cards_2003_pc if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_health_cards_2003_pc, Panel A) nocons bdec(3)

* Column 1. Panel B
reg num_health_cards_2003_pc i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_health_cards_2003_pc if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_health_cards_2003_pc, Panel B) nocons bdec(3)


use "DataBupati_PODES_2005_Add.dta", clear			

* Column 2. Panel A 
reg num_health_cards_2005_pc appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_health_cards_2005_pc if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_health_cards_2005_pc, Panel A) nocons bdec(3)

* Column 2. Panel B
reg num_health_cards_2005_pc i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_health_cards_2005_pc if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_health_cards_2005_pc, Panel B) nocons bdec(3)


use "DataBupati_PODES_2008_Add.dta", clear

* Column 3. Panel A 
reg num_health_cards_2008_ph appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_health_cards_2008_ph if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_health_cards_2008_ph, Panel A) nocons bdec(3)

* Column 3. Panel B
reg num_health_cards_2008_ph i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_health_cards_2008_ph if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_health_cards_2008_ph, Panel B) nocons bdec(3)


use "DataBupati_PODES_2011_Add.dta", clear
 
* Column 4. Panel A 
reg num_health_cards_2011_pc appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_health_cards_2011_pc if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_health_cards_2011_pc, Panel A) nocons bdec(3)

*Column 4. Panel B
reg num_health_cards_2011_pc i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
gen esample=e(sample)
sum num_health_cards_2011_pc if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", keep(i.appyr_predec) adds(Mean, `mean', clust, e(N_clust)) ctitle(num_health_cards_2011_pc, Panel B) nocons bdec(3)



use "DataBupati_SUSENAS09.dta", clear

foreach var of varlist free_health_jamkesmas blt_dum raskin_dum {

* Columns 5 to 7. Panel A
reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, cluster(id_district)
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', Panel A) adds(Mean, `mean', clust, e(N_clust))

* Columns 5 to 7. Panel B
reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, cluster(id_district)
gen esample=e(sample)
sum `var' if esample==1
local mean=r(mean)
drop esample
outreg2 using "BT15.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', Panel B) adds(Mean, `mean', clust, e(N_clust))
		
}


*************************************************************************************************************
** Appendix B - Table 16A Robustness Check: Results Measured at Constant Time Lag since Mayoral Transition **
*************************************************************************************************************

capture erase  "BT16A.xls"
capture erase  "BT16A.txt"	

use "DataBupati_Election_2009.dta", clear

* Columns 1 to 5
foreach var of varlist gol_z_2004 gol_z_2009 gol_std_sample_1 gol_std_sample_2 gol_std_sample_3 {
	reg `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT16A.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var') adds(Mean, `mean', NumKabs, `numkab')
}


*************************************************************************************************************
** Appendix B - Table 16B Robustness Check: Results Measured at Constant Time Lag since Mayoral Transition **
*************************************************************************************************************

use "DataBupati_EGI.dta", clear

capture erase  "BT16B.xls"
capture erase  "BT16B.txt"
 
* Columns 2 & 3
foreach var of varlist bribe_AP_lag_sample_1 bribe_AP_lag_sample_2 {
reg `var' appyr_predec gol_1992_perc pdi_1992_perc empl_2550-empl_75100 yrs_business isdum*, cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT16B.xls", bdec(3) nocons ctitle(`var') keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
	}


*************************************************************************************************************	
** Appendix B - Table 16C Robustness Check: Results Measured at Constant Time Lag since Mayoral Transition **
*************************************************************************************************************
*** Please refer to the respective baseline results for the results displayed in Column 1
	
capture erase  "BT16C.xls"
capture erase  "BT16C.txt"

use "DataBupati_PODES_Panel.dta", clear 

* Columns 2 to 5. Panels A & B
foreach var of varlist z_score_edu_6yrs z_score_edu_56yrs  z_score_edu_9yrs z_score_edu_89yrs z_score_health_6yrs z_score_health_56yrs  z_score_health_9yrs z_score_health_89yrs {
	reg `var' appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT16C.xls", bdec(3) nocons ctitle(`var') keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
}

* Column 6. Panels A & B
foreach var of varlist z_score_edu_lag_all z_score_health_lag_all {
	reg `var' appyr_predec i.time_lag gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)
	outreg2 using "BT16C.xls", bdec(3) nocons ctitle(`var') keep(appyr_predec) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	drop esample temp
}

*********************************************************************************
** Appendix B - Table 17 Incidence of Conflict and Exposure to Soeharto Mayors **
*********************************************************************************

capture erase  "BT17.xls"
capture erase  "BT17.txt"	
 
use "DataBupati_UNSFIR.dta", clear

*** Restricting to UNSFIR-covered provinces

foreach var of varlist incidents totkil {

* Column 1. Panel A & Column 2. Panel A
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum* if UNSFIR_coverage==1, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', Panel A) adds(Mean, `mean', NumKabs, `numkab')
* Column 1. Panel B & Column 2. Panel B	
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum* if UNSFIR_coverage==1, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', Panel B) adds(Mean, `mean', NumKabs, `numkab')
	}
	
	
foreach var of varlist incidents totkil {

* Column 3. Panel A & Column 4. Panel A
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', Panel A) adds(Mean, `mean', NumKabs, `numkab')
* Column 3. Panel B & Column 4. Panel B
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', Panel B) adds(Mean, `mean', NumKabs, `numkab')	
	}
	

use "DataBupati_PODES_2005_Add.dta", clear			

* Column 5. Panel A		
	reg conflict_2005 appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum conflict_2005 if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(appyr_predec) ctitle(conflict_2005, Panel A) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')	
		
* Column 5. Panel B 
	reg conflict_2005 i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum conflict_2005 if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(conflict_2005, Panel B) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
	

use "DataBupati_PODES_2008_Add.dta", clear

* Column 6. Panel A		
	reg conflict_2008 appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum conflict_2008 if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(appyr_predec) ctitle(conflict_2008, Panel A) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')	
		
* Column 6. Panel B
	reg conflict_2008 i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum conflict_2008 if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(conflict_2008, Panel B) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
		

use "DataBupati_PODES_2011_Add.dta", clear

* Column 7. Panel A		
	reg conflict_2011 appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum conflict_2011 if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(appyr_predec) ctitle(conflict_2011, Panel A) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')	
		
* Column 7. Panel B 
	reg conflict_2011 i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum conflict_2011 if esample==1
	local mean=r(mean)
	egen temp=group(id_district) if esample==1
	sum temp
	local numkab=r(max)	
	drop esample temp
	outreg2 using "BT17.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(conflict_2011, Panel B) adds(Mean, `mean', clust, e(N_clust), NumKabs, `numkab')
		

******************************************************************************	
** Appendix B - Table 18 Robustness Check Public Good Results (Full Sample) **
******************************************************************************	
	
capture erase  "BT18.xls"
capture erase  "BT18.txt"		

use "DataBupati_PODES2011_Full.dta", clear

* Columns 1 to 3
foreach var in z_score_edu z_score_health z_score_services {
* Panel A
	reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT18.xls", bdec(3) nocons keep(appyr_predec) ctitle(`var', 2011) adds(Mean, `mean', clust, e(N_clust))
* Panel B
	reg  `var' i.appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district)
	gen esample=e(sample)
	sum `var' if esample==1
	local mean=r(mean)
	drop esample
	outreg2 using "BT18.xls", bdec(3) nocons keep(i.appyr_predec) ctitle(`var', 2011) adds(Mean, `mean', clust, e(N_clust))
	
	}
		
		
*************************************************************************************************************************		
** Appendix B - Table 19 Pre-Treatment Characteristics (separately for Last Soeharto Mayor served 5 versus more years) **
************************************************************************************************************************* 

capture erase  "BT19.xls"
capture erase  "BT19.txt"

use "DataBupati_Endogeneity.dta", clear

foreach xx in 1971 1977 1982 1987 1992 {
	gen gol=gol_`xx'_perc

reg  sixyears gol isd* if term_length>=5, robust
 outreg2 using "BT19.xls", bdec(3) keep(gol) nocons ctitle(PANEL A, Golkar `xx')

reg  sixyears gol isd* if term_length>=5, robust beta
 outreg2 using "BT19.xls", bdec(3) keep(gol) nocons stats(beta) ctitle(beta, Golkar `xx')
 
 drop gol
 }
 

reg  sixyears pdi_1992_perc isd* if term_length>=5, robust
 outreg2 using "BT19.xls", bdec(3) keep(pdi_1992_perc) nocons ctitle(PANEL A, PDI 1992)

reg  sixyears pdi_1992_perc isd* if term_length>=5, robust beta
 outreg2 using "BT19.xls", bdec(3) keep(pdi_1992_perc) nocons stats(beta) ctitle(beta, PDI 1992)
 
foreach yr in 1982 1987 1992 {

reg  sixyears herf_`yr' isd* if term_length>=5, robust
 outreg2 using "BT19.xls", bdec(3) keep(herf_`yr') nocons ctitle(PANEL A, herf `yr')

reg  sixyears herf_`yr' isd* if term_length>=5, robust beta
 outreg2 using "BT19.xls", bdec(3) keep(herf_`yr') nocons stats(beta) ctitle(beta, herf `yr')
 } 


global covarUNSFIR "incidents_avg_90_93 totkil_avg_90_93 totinj_avg_90_93"
	
foreach var in $covarUNSFIR{
 gen covar=`var'
 reg  sixyears covar isdum* if term_length>=5, robust
 outreg2 using "BT19.xls", bdec(3) keep(covar) nocons ctitle(PANEL B, `var')

 reg  sixyears covar isdum* if term_length>=5, robust
 outreg2 using "BT19.xls", bdec(3) keep(covar) nocons stats(beta) ctitle(beta, `var')
 
 drop covar
 } 
 
 
reg sixyears prev_term_length isd* if term_length>=5, robust
 outreg2 using "BT19.xls", bdec(3) keep(prev_term_length) nocons ctitle(PANEL B, prev_term_length)

reg sixyears prev_term_length isd* if term_length>=5, robust beta
 outreg2 using "BT19.xls", bdec(3) keep(prev_term_length) nocons stats(beta) ctitle(beta, prev_term_length)
 
 

use "DataBupati_PODES_1993.dta", clear 

# delimit ;
global covars "lpopulation_1993 num_pri_ph num_hs_ph num_kindgarden_ph 
safedrink garbage_bin toilet_pub electr_kersosene wide_mainroad" ;
# delimit cr

foreach var in $covars{
 gen covar=`var'
 reg  sixyears covar isdum* if term_length>=5, cluster(id_district) 
 outreg2 using "BT19.xls", bdec(3) keep(covar) nocons ctitle(PANEL C, `var') adds(clust, e(N_clust))
 
 reg  sixyears covar isdum* if term_length>=5, beta
 outreg2 using "BT19.xls", bdec(3) keep(covar) nocons stats(beta) ctitle(beta, `var')

 drop covar
 }
 
 
reg  sixyears popdensity_1993 isdum* if term_length>=5, cluster(id_district) 
outreg2 using "BT19.xls", bdec(3) keep(popdensity_1993) nocons ctitle(PANEL C, popdensity_1993) adds(clust, e(N_clust))
 
reg  sixyears popdensity_1993 isdum* if term_length>=5, beta
outreg2 using "BT19.xls", bdec(3) keep(popdensity_1993) nocons stats(beta) ctitle(beta, popdensity_1993)

reg  sixyears rel_frag isdum* if term_length>=5, cluster(id_district) 
outreg2 using "BT19.xls", bdec(3) keep(rel_frag) nocons ctitle(PANEL C, rel_frag) adds(clust, e(N_clust))
 
reg  sixyears rel_frag isdum* if term_length>=5, beta
outreg2 using "BT19.xls", bdec(3) keep(rel_frag) nocons stats(beta) ctitle(beta, rel_frag)
 
 

# delimit ;
global covars_health "num_puskesmas_ph num_doctors_ph num_midwives_ph tba_dum";
# delimit cr

foreach var in $covars_health{
 gen covar=`var'
 reg  sixyears covar isdum* if health_complete_dum==1 & term_length>=5, cluster(id_district) 
 outreg2 using "BT19.xls", bdec(3) keep(covar) nocons ctitle(PANEL C, `var') adds(clust, e(N_clust))
 
 reg  sixyears covar isdum* if health_complete_dum==1 & term_length>=5, beta
 outreg2 using "BT19.xls", bdec(3) keep(covar) nocons stats(beta) ctitle(beta, `var') 

 drop covar
 }
 
 
use "DataBupati_Endogeneity.dta", clear


global covars_econ "ltot_rev_pc_1994 ltot_loc_rev_pc_1994"

foreach var in $covars_econ {
 gen covar=`var'
 reg  sixyears covar isdum* if term_length>=5, robust
 outreg2 using "BT19.xls", bdec(3) keep(covar) nocons ctitle(PANEL C, `var')
 
 reg  sixyears covar isdum* if term_length>=5, robust beta
 outreg2 using "BT19.xls", bdec(3) keep(covar) stats(beta) nocons ctitle(beta, `var')

 drop covar
 }


****************************************************************************************************************** 
** Appendix B - Figure 3. Effects of Exposure to Soeharto Mayors on Public Good Provision (2011 Village Census) **
******************************************************************************************************************

use "DataBupati_PODES_2011.dta", clear	

foreach var in pc_num_pri_std pc_num_hs_std pc_num_kindgarden_std z_score_edu pc_num_puskesmas_std pc_num_doctors_std pc_num_midwives_std tba_dum z_score_health {

reg  `var' appyr_predec gol_1992_perc pdi_1992_perc isdum* lpop*, cluster(id_district) level(90)
parmest, level(90) saving("`var'.dta", replace)

}

foreach var in pc_num_pri_std pc_num_hs_std pc_num_kindgarden_std z_score_edu pc_num_puskesmas_std pc_num_doctors_std pc_num_midwives_std tba_dum z_score_health {
	use "`var'.dta", clear
	keep parm estimate min90 max90
	gen depvar_name="`var'"
	keep if parm=="appyr_predec"
	save "`var'.dta",replace
	}
	
use "pc_num_pri_std.dta", clear

foreach var in pc_num_hs_std pc_num_kindgarden_std z_score_edu pc_num_puskesmas_std pc_num_doctors_std pc_num_midwives_std tba_dum z_score_health {

append using "`var'.dta"

}

save "Figure_AppB_3_data.dta", replace	

use "Figure_AppB_3_data.dta", clear

keep if parm=="appyr_predec"

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Education" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Health" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="separation_1" if depvar_name==""
drop flag

gen order=.
replace order=1 if depvar_name=="Education"
replace depvar_name="z-score education" if depvar_name=="z_score_edu"
replace order=2 if depvar_name=="z-score education"
replace depvar_name="Number of kindergartens" if depvar_name=="pc_num_kindgarden_std"
replace order=3 if depvar_name=="Number of kindergartens"
replace depvar_name="Number of primary schools" if depvar_name=="pc_num_pri_std"
replace order=4 if depvar_name=="Number of primary schools"
replace depvar_name="Number of high schools" if depvar_name=="pc_num_hs_std"
replace order=5 if depvar_name=="Number of high schools"
replace order=6 if depvar_name=="separation_1"
replace depvar_name="." if depvar_name=="separation_1"
replace order=7 if depvar_name=="Health"
replace depvar_name="z-score health" if depvar_name=="z_score_health"
replace order=8 if depvar_name=="z-score health"
replace depvar_name="Number of basic health centers" if depvar_name=="pc_num_puskesmas_std"
replace order=9 if depvar_name=="Number of basic health centers"
replace depvar_name="Number of doctors" if depvar_name=="pc_num_doctors_std"
replace order=10 if depvar_name=="Number of doctors"
replace depvar_name="Number of midwives" if depvar_name=="pc_num_midwives_std"
replace order=11 if depvar_name=="Number of midwives"
replace depvar_name="Not using traditional birth attendants" if depvar_name=="tba_dum"
replace order=12 if depvar_name=="Not using traditional birth attendants"

sort order
sencode depvar_name, gen(parm_id) gsort(+order)

#delimit ;
eclplot estimate min90 max90 parm_id, horizontal
estopts(msymbol(O) mcolor(edkblue))
ciopts(lcolor(gs7))
ylabel(1(1)20, labcolor(white))
ylabel(1 "{bf:Education}" 2 "z-score education" 3 "Number of kindergartens" 4 "Number of primary schools" 5 "Number of high schools" ///
7 "{bf:Health}" 8 "z-score health" 9 "Number of basic health centers" 10 "Number of doctors" 11 "Number of midwives" 12 "Not using traditional birth attendants", nogrid labcolor(black)) ytitle("")

xlabel(-0.15(0.05)0.05) xtitle("Regression coefficient") 
yline(1, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
yline(7, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
yline(14, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
xline(0, lcolor(black)) 
xline(-0.05, lcolor(gs14)) 
xline(-0.10, lcolor(gs14)) 
graphregion(color(white)) bgcolor(white)
;
#delimit cr
graph export "AppB_Figure_3.pdf", replace


* Erase data sets produced during intermediate steps

foreach var in pc_num_pri_std pc_num_hs_std pc_num_kindgarden_std z_score_edu ///
pc_num_puskesmas_std pc_num_doctors_std ///
pc_num_midwives_std tba_dum z_score_health {
capture erase "`var'.dta"
}

capture erase "Figure_AppB_3_data.dta"

 

**********************************************************************		
** Appendix B - Figure 4. Effects on General Allocation Grant (DAU) **
**********************************************************************

use "DataBupati_LocalBudgets.dta", clear

forval i=2001(1)2007 {
	
reg  cent_gov_trans_dau_pc_`i' appyr_predec gol_1992_perc pdi_1992_perc isdum*, robust
parmest, saving("cent_gov_trans_dau_pc_`i'.dta", replace)

}

forval i=2001(1)2007 {
	
	use "cent_gov_trans_dau_pc_`i'.dta", clear
	keep parm estimate min95 max95
	gen depvar_name="cent_gov_trans_dau_pc_`i'"
	gen year=`i'
	keep if parm=="appyr_predec"
	save "cent_gov_trans_dau_pc_`i'.dta",replace

}

use "cent_gov_trans_dau_pc_2001.dta", clear

forval i=2002(1)2007 {
	
append using "cent_gov_trans_dau_pc_`i'.dta"

}

save "Figure_AppB_4_data.dta", replace


use "Figure_AppB_4_data.dta", clear

keep if parm=="appyr_predec"

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Government: Wahid" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Government: Megawati" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="Government: S.B. Yudhoyono" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="separation_1" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="separation_2" if depvar_name==""
drop flag

local numobs= _N+1
set obs `numobs' 
gen flag=_n
replace depvar_name="separation_3" if depvar_name==""
drop flag

gen order=.
replace order=1 if depvar_name=="Government: Wahid"
replace order=2 if depvar_name=="cent_gov_trans_dau_pc_2001" & year==2001
replace depvar_name="2001" if depvar_name=="cent_gov_trans_dau_pc_2001" & year==2001
replace order=3 if depvar_name=="separation_2"
replace depvar_name=".." if depvar_name=="separation_2"
replace order=4 if depvar_name=="Government: Megawati"
replace order=5 if depvar_name=="cent_gov_trans_dau_pc_2002" & year==2002
replace depvar_name="2002" if depvar_name=="cent_gov_trans_dau_pc_2002" & year==2002
replace order=6 if depvar_name=="cent_gov_trans_dau_pc_2003" & year==2003
replace depvar_name="2003" if depvar_name=="cent_gov_trans_dau_pc_2003" & year==2003
replace order=7 if depvar_name=="cent_gov_trans_dau_pc_2004" & year==2004
replace depvar_name="2004" if depvar_name=="cent_gov_trans_dau_pc_2004" & year==2004
replace order=8 if depvar_name=="separation_3"
replace depvar_name="..." if depvar_name=="separation_3"
replace order=9 if depvar_name=="Government: S.B. Yudhoyono"
replace order=10 if depvar_name=="cent_gov_trans_dau_pc_2005" & year==2005
replace depvar_name="2005" if depvar_name=="cent_gov_trans_dau_pc_2005" & year==2005
replace order=11 if depvar_name=="cent_gov_trans_dau_pc_2006" & year==2006
replace depvar_name="2006" if depvar_name=="cent_gov_trans_dau_pc_2006" & year==2006
replace order=12 if depvar_name=="cent_gov_trans_dau_pc_2007" & year==2007
replace depvar_name="2007" if depvar_name=="cent_gov_trans_dau_pc_2007" & year==2007

drop if order==.
sort order
sencode depvar_name, gen(parm_id) gsort(+order)

#delimit ;
eclplot estimate min95 max95 parm_id, horizontal
estopts(msymbol(O) mcolor(edkblue))
ciopts(lcolor(gs7))
ylabel(1(1)12, labcolor(white))
ylabel( 1 "{bf:Government: Wahid}" ///
2 "2001" 4 "{bf:Government: Megawati}" 5 "2002" 6 "2003" ///
7 "2004" 9 "{bf:Government: S.B. Yudhoyono}" 10 "2005" 11 "2006" 12 "2007", nogrid labcolor(black)) ytitle("")
xlabel(-0.15(0.05)0.05) xtitle("Regression Coefficient Year of Appointment") 
yline(1, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
yline(4, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
yline(9, lwidth(0.2) lcolor(gs14) lpattern(dash)) 
xline(0.05, lcolor(gs14))
xline(0, lcolor(black)) 
xline(-0.05, lcolor(gs14)) 
xline(-0.10, lcolor(gs14)) 
xline(-0.15, lcolor(gs14)) 
graphregion(color(white)) bgcolor(white)
;
#delimit cr
graph export "AppB_Figure_4.pdf", replace

* Erase data sets produced during intermediate steps

forval i=2001(1)2007 {

capture erase "cent_gov_trans_dau_pc_`i'.dta"

}
capture erase "Figure_AppB_4_data.dta"


**********************************************************************		
** Appendix B - Figure 5. Effects on Special Earmarked Grant (DAK) ***
**********************************************************************
* Please refer to Figure 3 in the section for results of the main paper.
